Index: /branches/eam_branches/ipp-20130904/PS-IPP-PStamp/lib/PS/IPP/PStamp/RequestFile.pm
===================================================================
--- /branches/eam_branches/ipp-20130904/PS-IPP-PStamp/lib/PS/IPP/PStamp/RequestFile.pm	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/PS-IPP-PStamp/lib/PS/IPP/PStamp/RequestFile.pm	(revision 36192)
@@ -37,6 +37,6 @@
                     $PSTAMP_USE_IMFILE_ID
                     $PSTAMP_NO_WAIT_FOR_UPDATE
-                    $PSTAMP_REQUEST_UNCENSORED
-                    $PSTAMP_REQUIRE_UNCENSORED
+                    $PSTAMP_SELECT_EXPJPEG
+                    $PSTAMP_SELECT_NUMJPEG
                     $PSTAMP_SUCCESS
                     $PSTAMP_FIRST_ERROR_CODE
@@ -55,4 +55,5 @@
                     $PSTAMP_NO_OVERLAP
                     $PSTAMP_NOT_AUTHORIZED
+                    $PSTAMP_NO_VALID_PIXELS
                     );
 our %EXPORT_TAGS = (standard => [@EXPORT_OK]);
@@ -84,7 +85,10 @@
 our $PSTAMP_NO_WAIT_FOR_UPDATE = 32768;
 
-# these bits will be repurposed
-our $PSTAMP_REQUEST_UNCENSORED = 0x10000;
-our $PSTAMP_REQUIRE_UNCENSORED = 0x20000;
+our $PSTAMP_SELECT_EXPJPEG     = 0x10000;
+our $PSTAMP_SELECT_NUMJPEG     = 0x20000;
+
+# these bits have been repurposed. They were only exposed to MOPS and IFA and they have adapted.
+#our $PSTAMP_REQUEST_UNCENSORED = 0x10000;
+#our $PSTAMP_REQUIRE_UNCENSORED = 0x20000;
 
 # job and result codes
Index: /branches/eam_branches/ipp-20130904/dvodist/Makefile.in
===================================================================
--- /branches/eam_branches/ipp-20130904/dvodist/Makefile.in	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/dvodist/Makefile.in	(revision 36192)
@@ -63,4 +63,5 @@
 $(TGT-IPPDATA)/photladder.20130107.subset/ubercal-fits/index.php \
 $(TGT-IPPDATA)/photladder.20130107.subset/ubercal-csv/index.php \
+$(TGT-IPPDATA)/ps1.filters/index.php \
 $(TGT-IPPDATA)/catdir.syn.test/index.php \
 $(TGT-IPPDATA)/catdir.syn.test/n3000/index.php \
@@ -73,4 +74,5 @@
 $(TGT-IPPDATA)/ipp.css \
 $(TGT-IPPDATA)/PScolorlogo2.jpg \
+$(TGT-IPPDATA)/ps1.filters/apj425122t3_mrt.txt \
 $(TGT-IPPDATA)/docs/photladder-1206.20130301.pdf \
 $(TGT-IPPDATA)/docs/2mass.compare/dH.allsky.20120528.v3.png \
Index: /branches/eam_branches/ipp-20130904/dvodist/ippdata/index.mkd
===================================================================
--- /branches/eam_branches/ipp-20130904/dvodist/ippdata/index.mkd	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/dvodist/ippdata/index.mkd	(revision 36192)
@@ -45,2 +45,3 @@
 @ PS1 Photladder, 12.01       : photladder.20130107.subset : dir   : dir1  : Photometric Reference Ladder, Release 12.01
 @ Synthetic Photometry DVO    : catdir.syn.test            : dir   : dir2  : Demonstration DVO Database
+@ PS1 Filter Bandpasses       : ps1.filters                : dir   : dir1  : PS1 Filter Bandpass Tables
Index: /branches/eam_branches/ipp-20130904/dvodist/ippdata/ps1.filters/apj425122t3_mrt.txt
===================================================================
--- /branches/eam_branches/ipp-20130904/dvodist/ippdata/ps1.filters/apj425122t3_mrt.txt	(revision 36192)
+++ /branches/eam_branches/ipp-20130904/dvodist/ippdata/ps1.filters/apj425122t3_mrt.txt	(revision 36192)
@@ -0,0 +1,747 @@
+Title: The Pan-STARRS1 Photometric System 
+Authors: Tonry J.L., Stubbs C.W., Lykke K.R., Doherty P., Shivvers I.S., 
+         Burgett W.S., Chambers K.C., Hodapp K.W., Kaiser N., Kudritzki R.-P., 
+         Magnier E.A., Morgan J.S., Price P.A., Wainscoat R.J. 
+Table: Pan-STARRS1 Bandpasses
+================================================================================
+Byte-by-byte Description of file: apj425122t3_mrt.txt
+--------------------------------------------------------------------------------
+   Bytes Format Units Label  Explanations
+--------------------------------------------------------------------------------
+   1-  4 I4     nm    Wave   Wavelength  
+   6- 10 F5.3   m2    Open   The open bandpass capture cross-section (1)
+  12- 16 F5.3   m2    gp1    The gp1 bandpass capture cross-section (1)
+  18- 22 F5.3   m2    rp1    The rp1 bandpass capture cross-section (1)
+  24- 28 F5.3   m2    ip1    The ip1 bandpass capture cross-section (1)
+  30- 34 F5.3   m2    zp1    The zp1 bandpass capture cross-section (1)
+  36- 40 F5.3   m2    yp1    The yp1 bandpass capture cross-section (1)
+  42- 46 F5.3   m2    wp1    The wp1 bandpass capture cross-section (1)
+  48- 52 F5.3   ---   Aero   Aerosol scattering transmission (2)
+  54- 58 F5.3   ---   Ray    Rayleigh scattering transmission (2)
+  60- 64 F5.3   ---   Mol    Molecular absroption transmission (2)
+--------------------------------------------------------------------------------
+Note (1): Including the nominal 1.2 airmasses of the Pan-STARRS1 standard
+          atmospheric extinction.  In units of m^2^-e/photon.
+Note (2): Of the nominal 1.2 airmasses of the  Pan-STARRS1 standard atmosphere.
+--------------------------------------------------------------------------------
+ 380 0.096 0.000 0.000 0.000 0.000 0.000 0.000 0.945 0.694 0.998 
+ 381 0.099 0.000 0.000 0.000 0.000 0.000 0.000 0.945 0.697 0.999 
+ 382 0.103 0.000 0.000 0.000 0.000 0.000 0.000 0.945 0.700 0.999 
+ 383 0.106 0.000 0.000 0.000 0.000 0.000 0.000 0.945 0.703 1.000 
+ 384 0.110 0.000 0.000 0.000 0.000 0.000 0.000 0.945 0.705 1.000 
+ 385 0.113 0.000 0.000 0.000 0.000 0.000 0.000 0.945 0.708 1.000 
+ 386 0.117 0.000 0.000 0.000 0.000 0.000 0.000 0.946 0.711 1.000 
+ 387 0.121 0.000 0.000 0.000 0.000 0.000 0.000 0.946 0.713 1.000 
+ 388 0.125 0.000 0.000 0.000 0.000 0.000 0.001 0.946 0.716 1.000 
+ 389 0.129 0.000 0.000 0.000 0.000 0.000 0.006 0.946 0.718 1.000 
+ 390 0.133 0.001 0.000 0.000 0.000 0.000 0.006 0.946 0.721 1.000 
+ 391 0.137 0.001 0.000 0.000 0.000 0.000 0.005 0.946 0.723 1.000 
+ 392 0.142 0.001 0.000 0.000 0.000 0.000 0.005 0.946 0.725 1.000 
+ 393 0.146 0.002 0.000 0.000 0.000 0.000 0.005 0.947 0.728 1.000 
+ 394 0.151 0.004 0.000 0.000 0.000 0.000 0.006 0.947 0.731 1.000 
+ 395 0.156 0.007 0.000 0.000 0.000 0.000 0.006 0.947 0.733 1.000 
+ 396 0.161 0.012 0.000 0.000 0.000 0.000 0.008 0.947 0.735 1.000 
+ 397 0.166 0.021 0.000 0.000 0.000 0.000 0.010 0.947 0.738 1.000 
+ 398 0.171 0.035 0.000 0.000 0.000 0.000 0.014 0.947 0.740 1.000 
+ 399 0.176 0.053 0.000 0.000 0.000 0.000 0.021 0.947 0.742 1.000 
+ 400 0.182 0.073 0.000 0.000 0.000 0.000 0.032 0.948 0.744 1.000 
+ 401 0.188 0.096 0.000 0.000 0.000 0.000 0.049 0.948 0.746 1.000 
+ 402 0.194 0.118 0.000 0.000 0.000 0.000 0.071 0.948 0.749 1.000 
+ 403 0.199 0.135 0.000 0.000 0.000 0.000 0.096 0.948 0.751 1.000 
+ 404 0.205 0.147 0.000 0.000 0.000 0.000 0.123 0.948 0.753 1.000 
+ 405 0.210 0.157 0.000 0.000 0.000 0.000 0.148 0.948 0.755 1.000 
+ 406 0.217 0.163 0.000 0.000 0.000 0.000 0.169 0.948 0.758 1.000 
+ 407 0.223 0.167 0.000 0.000 0.000 0.000 0.186 0.948 0.760 1.000 
+ 408 0.228 0.171 0.000 0.000 0.000 0.000 0.198 0.949 0.762 1.000 
+ 409 0.235 0.175 0.000 0.000 0.000 0.000 0.208 0.949 0.764 1.000 
+ 410 0.242 0.181 0.000 0.000 0.000 0.000 0.216 0.949 0.766 1.000 
+ 411 0.248 0.186 0.000 0.000 0.000 0.000 0.223 0.949 0.768 1.000 
+ 412 0.254 0.192 0.000 0.000 0.000 0.000 0.231 0.949 0.770 1.000 
+ 413 0.261 0.199 0.000 0.000 0.000 0.000 0.240 0.949 0.772 1.000 
+ 414 0.268 0.204 0.000 0.000 0.000 0.000 0.248 0.949 0.774 1.000 
+ 415 0.276 0.206 0.000 0.000 0.000 0.000 0.257 0.949 0.776 1.000 
+ 416 0.284 0.208 0.000 0.000 0.000 0.000 0.265 0.950 0.778 1.000 
+ 417 0.291 0.211 0.000 0.000 0.000 0.000 0.272 0.950 0.780 1.000 
+ 418 0.298 0.217 0.000 0.000 0.000 0.000 0.278 0.950 0.782 1.000 
+ 419 0.305 0.225 0.000 0.000 0.000 0.000 0.284 0.950 0.784 1.000 
+ 420 0.312 0.233 0.000 0.000 0.000 0.000 0.288 0.950 0.785 1.000 
+ 421 0.318 0.240 0.000 0.000 0.000 0.000 0.293 0.950 0.787 1.000 
+ 422 0.324 0.246 0.000 0.000 0.000 0.000 0.297 0.950 0.789 1.000 
+ 423 0.331 0.249 0.000 0.000 0.000 0.000 0.303 0.950 0.791 1.000 
+ 424 0.338 0.250 0.000 0.000 0.000 0.000 0.308 0.951 0.792 1.000 
+ 425 0.344 0.250 0.000 0.000 0.000 0.000 0.315 0.951 0.794 1.000 
+ 426 0.351 0.253 0.000 0.000 0.000 0.000 0.322 0.951 0.796 1.000 
+ 427 0.356 0.259 0.000 0.000 0.000 0.000 0.328 0.951 0.798 1.000 
+ 428 0.362 0.268 0.000 0.000 0.000 0.000 0.335 0.951 0.799 1.000 
+ 429 0.368 0.277 0.000 0.000 0.000 0.000 0.342 0.951 0.801 1.000 
+ 430 0.374 0.286 0.000 0.000 0.000 0.000 0.350 0.951 0.803 1.000 
+ 431 0.380 0.295 0.000 0.000 0.000 0.000 0.358 0.951 0.804 1.000 
+ 432 0.386 0.300 0.000 0.000 0.000 0.000 0.367 0.952 0.806 1.000 
+ 433 0.392 0.302 0.000 0.000 0.000 0.000 0.375 0.952 0.808 0.999 
+ 434 0.398 0.302 0.000 0.000 0.000 0.000 0.382 0.952 0.809 0.999 
+ 435 0.403 0.304 0.000 0.000 0.000 0.000 0.389 0.952 0.810 0.999 
+ 436 0.409 0.309 0.000 0.000 0.000 0.000 0.396 0.952 0.812 0.999 
+ 437 0.415 0.316 0.000 0.000 0.000 0.000 0.402 0.952 0.815 0.999 
+ 438 0.420 0.323 0.000 0.000 0.000 0.000 0.408 0.952 0.817 0.999 
+ 439 0.425 0.330 0.000 0.000 0.000 0.000 0.411 0.952 0.817 0.999 
+ 440 0.430 0.336 0.000 0.000 0.000 0.000 0.416 0.952 0.819 0.999 
+ 441 0.436 0.340 0.000 0.000 0.000 0.000 0.421 0.953 0.821 0.999 
+ 442 0.442 0.341 0.000 0.000 0.000 0.000 0.426 0.953 0.823 0.999 
+ 443 0.447 0.342 0.000 0.000 0.000 0.000 0.430 0.953 0.824 0.998 
+ 444 0.451 0.344 0.000 0.000 0.000 0.000 0.433 0.953 0.825 0.999 
+ 445 0.455 0.348 0.000 0.000 0.000 0.000 0.437 0.953 0.826 0.999 
+ 446 0.460 0.354 0.000 0.000 0.000 0.000 0.442 0.953 0.828 0.999 
+ 447 0.465 0.361 0.000 0.000 0.000 0.000 0.446 0.953 0.830 0.999 
+ 448 0.470 0.368 0.000 0.000 0.000 0.000 0.449 0.953 0.830 0.999 
+ 449 0.474 0.374 0.000 0.000 0.000 0.000 0.453 0.953 0.832 0.999 
+ 450 0.478 0.380 0.000 0.000 0.000 0.000 0.458 0.954 0.834 0.999 
+ 451 0.482 0.386 0.000 0.000 0.000 0.000 0.462 0.954 0.835 0.999 
+ 452 0.486 0.392 0.000 0.000 0.000 0.000 0.467 0.954 0.836 0.999 
+ 453 0.490 0.396 0.000 0.000 0.000 0.000 0.470 0.954 0.838 0.999 
+ 454 0.493 0.398 0.000 0.000 0.000 0.000 0.473 0.954 0.839 0.999 
+ 455 0.497 0.398 0.000 0.000 0.000 0.000 0.476 0.954 0.841 0.999 
+ 456 0.500 0.394 0.000 0.000 0.000 0.000 0.480 0.954 0.842 0.998 
+ 457 0.503 0.388 0.000 0.000 0.000 0.000 0.484 0.954 0.843 0.998 
+ 458 0.506 0.384 0.000 0.000 0.000 0.000 0.488 0.954 0.844 0.998 
+ 459 0.509 0.382 0.000 0.000 0.000 0.000 0.491 0.954 0.845 0.998 
+ 460 0.512 0.384 0.000 0.000 0.000 0.000 0.494 0.955 0.847 0.997 
+ 461 0.514 0.388 0.000 0.000 0.000 0.000 0.497 0.955 0.848 0.997 
+ 462 0.517 0.393 0.000 0.000 0.000 0.000 0.500 0.955 0.849 0.997 
+ 463 0.520 0.396 0.000 0.000 0.000 0.000 0.503 0.955 0.851 0.997 
+ 464 0.521 0.396 0.000 0.000 0.000 0.000 0.507 0.955 0.851 0.997 
+ 465 0.525 0.396 0.000 0.000 0.000 0.000 0.511 0.955 0.853 0.997 
+ 466 0.528 0.397 0.000 0.000 0.000 0.000 0.515 0.955 0.855 0.997 
+ 467 0.530 0.397 0.000 0.000 0.000 0.000 0.517 0.955 0.856 0.997 
+ 468 0.532 0.399 0.000 0.000 0.000 0.000 0.518 0.955 0.856 0.997 
+ 469 0.534 0.400 0.000 0.000 0.000 0.000 0.516 0.955 0.858 0.997 
+ 470 0.537 0.401 0.000 0.000 0.000 0.000 0.512 0.956 0.859 0.996 
+ 471 0.539 0.402 0.000 0.000 0.000 0.000 0.511 0.956 0.860 0.996 
+ 472 0.541 0.403 0.000 0.000 0.000 0.000 0.511 0.956 0.861 0.996 
+ 473 0.542 0.405 0.000 0.000 0.000 0.000 0.509 0.956 0.863 0.995 
+ 474 0.543 0.408 0.000 0.000 0.000 0.000 0.506 0.956 0.863 0.995 
+ 475 0.544 0.413 0.000 0.000 0.000 0.000 0.504 0.956 0.864 0.994 
+ 476 0.545 0.418 0.000 0.000 0.000 0.000 0.503 0.956 0.866 0.992 
+ 477 0.547 0.424 0.000 0.000 0.000 0.000 0.505 0.956 0.867 0.991 
+ 478 0.548 0.431 0.000 0.000 0.000 0.000 0.510 0.956 0.868 0.991 
+ 479 0.550 0.437 0.000 0.000 0.000 0.000 0.518 0.956 0.869 0.991 
+ 480 0.552 0.441 0.000 0.000 0.000 0.000 0.526 0.957 0.870 0.992 
+ 481 0.554 0.444 0.000 0.000 0.000 0.000 0.533 0.957 0.871 0.992 
+ 482 0.555 0.446 0.000 0.000 0.000 0.000 0.538 0.957 0.872 0.992 
+ 483 0.557 0.448 0.000 0.000 0.000 0.000 0.540 0.957 0.873 0.993 
+ 484 0.558 0.451 0.000 0.000 0.000 0.000 0.542 0.957 0.874 0.993 
+ 485 0.559 0.453 0.000 0.000 0.000 0.000 0.542 0.957 0.875 0.993 
+ 486 0.561 0.456 0.000 0.000 0.000 0.000 0.542 0.957 0.876 0.994 
+ 487 0.562 0.458 0.000 0.000 0.000 0.000 0.543 0.957 0.877 0.994 
+ 488 0.564 0.460 0.000 0.000 0.000 0.000 0.546 0.957 0.878 0.994 
+ 489 0.565 0.460 0.000 0.000 0.000 0.000 0.547 0.957 0.878 0.994 
+ 490 0.567 0.459 0.000 0.000 0.000 0.000 0.550 0.957 0.880 0.993 
+ 491 0.568 0.455 0.000 0.000 0.000 0.000 0.552 0.958 0.881 0.993 
+ 492 0.570 0.451 0.000 0.000 0.000 0.000 0.553 0.958 0.882 0.993 
+ 493 0.572 0.450 0.000 0.000 0.000 0.000 0.554 0.958 0.883 0.993 
+ 494 0.574 0.453 0.000 0.000 0.000 0.000 0.555 0.958 0.883 0.993 
+ 495 0.575 0.459 0.000 0.000 0.000 0.000 0.557 0.958 0.884 0.993 
+ 496 0.577 0.463 0.000 0.000 0.000 0.000 0.559 0.958 0.885 0.992 
+ 497 0.579 0.467 0.000 0.000 0.000 0.000 0.561 0.958 0.886 0.992 
+ 498 0.581 0.471 0.000 0.000 0.000 0.000 0.562 0.958 0.887 0.991 
+ 499 0.582 0.472 0.000 0.000 0.000 0.000 0.561 0.958 0.888 0.991 
+ 500 0.582 0.471 0.000 0.000 0.000 0.000 0.559 0.958 0.889 0.990 
+ 501 0.583 0.468 0.000 0.000 0.000 0.000 0.559 0.958 0.890 0.989 
+ 502 0.584 0.466 0.000 0.000 0.000 0.000 0.561 0.958 0.891 0.988 
+ 503 0.585 0.463 0.000 0.000 0.000 0.000 0.564 0.959 0.891 0.987 
+ 504 0.587 0.459 0.000 0.000 0.000 0.000 0.567 0.959 0.892 0.986 
+ 505 0.589 0.457 0.000 0.000 0.000 0.000 0.571 0.959 0.893 0.986 
+ 506 0.591 0.456 0.000 0.000 0.000 0.000 0.573 0.959 0.894 0.986 
+ 507 0.594 0.455 0.000 0.000 0.000 0.000 0.574 0.959 0.895 0.986 
+ 508 0.596 0.456 0.000 0.000 0.000 0.000 0.575 0.959 0.896 0.986 
+ 509 0.598 0.456 0.000 0.000 0.000 0.000 0.577 0.959 0.896 0.987 
+ 510 0.601 0.457 0.000 0.000 0.000 0.000 0.580 0.959 0.897 0.987 
+ 511 0.602 0.458 0.000 0.000 0.000 0.000 0.581 0.959 0.898 0.987 
+ 512 0.604 0.459 0.000 0.000 0.000 0.000 0.583 0.959 0.899 0.987 
+ 513 0.605 0.461 0.000 0.000 0.000 0.000 0.583 0.959 0.899 0.987 
+ 514 0.607 0.465 0.000 0.000 0.000 0.000 0.582 0.959 0.900 0.987 
+ 515 0.609 0.469 0.000 0.000 0.000 0.000 0.582 0.960 0.901 0.986 
+ 516 0.611 0.473 0.000 0.000 0.000 0.000 0.582 0.960 0.902 0.986 
+ 517 0.613 0.475 0.000 0.000 0.000 0.000 0.583 0.960 0.903 0.986 
+ 518 0.615 0.476 0.000 0.000 0.000 0.000 0.586 0.960 0.904 0.985 
+ 519 0.616 0.475 0.000 0.000 0.000 0.000 0.590 0.960 0.904 0.985 
+ 520 0.617 0.473 0.000 0.000 0.000 0.000 0.594 0.960 0.905 0.985 
+ 521 0.618 0.472 0.000 0.000 0.000 0.000 0.598 0.960 0.906 0.984 
+ 522 0.620 0.473 0.000 0.000 0.000 0.000 0.602 0.960 0.906 0.984 
+ 523 0.622 0.473 0.000 0.000 0.000 0.000 0.606 0.960 0.907 0.983 
+ 524 0.624 0.474 0.000 0.000 0.000 0.000 0.609 0.960 0.908 0.982 
+ 525 0.626 0.473 0.000 0.000 0.000 0.000 0.612 0.960 0.908 0.981 
+ 526 0.627 0.472 0.000 0.000 0.000 0.000 0.615 0.960 0.909 0.980 
+ 527 0.629 0.474 0.000 0.000 0.000 0.000 0.617 0.960 0.910 0.979 
+ 528 0.630 0.477 0.000 0.000 0.000 0.000 0.619 0.961 0.910 0.978 
+ 529 0.632 0.483 0.001 0.000 0.000 0.000 0.621 0.961 0.911 0.978 
+ 530 0.634 0.489 0.001 0.000 0.000 0.000 0.623 0.961 0.912 0.977 
+ 531 0.635 0.495 0.001 0.000 0.000 0.000 0.625 0.961 0.912 0.976 
+ 532 0.637 0.498 0.001 0.000 0.000 0.000 0.627 0.961 0.913 0.976 
+ 533 0.640 0.500 0.001 0.000 0.000 0.000 0.629 0.961 0.914 0.975 
+ 534 0.643 0.501 0.002 0.000 0.000 0.000 0.631 0.961 0.914 0.975 
+ 535 0.645 0.502 0.002 0.000 0.000 0.000 0.633 0.961 0.915 0.975 
+ 536 0.647 0.502 0.003 0.000 0.000 0.000 0.635 0.961 0.916 0.976 
+ 537 0.649 0.502 0.004 0.000 0.000 0.000 0.637 0.961 0.916 0.976 
+ 538 0.651 0.502 0.005 0.000 0.000 0.000 0.639 0.961 0.917 0.976 
+ 539 0.653 0.502 0.008 0.000 0.000 0.000 0.640 0.961 0.917 0.975 
+ 540 0.654 0.501 0.011 0.000 0.000 0.000 0.641 0.961 0.918 0.975 
+ 541 0.656 0.500 0.017 0.000 0.000 0.000 0.644 0.962 0.919 0.974 
+ 542 0.659 0.496 0.026 0.000 0.000 0.000 0.647 0.962 0.919 0.974 
+ 543 0.661 0.493 0.040 0.000 0.000 0.000 0.649 0.962 0.920 0.974 
+ 544 0.663 0.489 0.062 0.000 0.000 0.000 0.651 0.962 0.920 0.973 
+ 545 0.667 0.486 0.093 0.000 0.000 0.000 0.654 0.962 0.921 0.973 
+ 546 0.670 0.481 0.134 0.000 0.000 0.000 0.656 0.962 0.921 0.972 
+ 547 0.671 0.467 0.184 0.000 0.000 0.000 0.657 0.962 0.922 0.972 
+ 548 0.672 0.438 0.242 0.000 0.000 0.000 0.658 0.962 0.923 0.972 
+ 549 0.673 0.390 0.305 0.000 0.000 0.000 0.660 0.962 0.923 0.972 
+ 550 0.675 0.323 0.367 0.000 0.000 0.000 0.662 0.962 0.924 0.971 
+ 551 0.678 0.248 0.423 0.000 0.000 0.000 0.665 0.962 0.924 0.971 
+ 552 0.682 0.175 0.469 0.000 0.000 0.000 0.668 0.962 0.925 0.971 
+ 553 0.685 0.113 0.504 0.000 0.000 0.000 0.670 0.962 0.925 0.971 
+ 554 0.688 0.068 0.528 0.000 0.000 0.000 0.672 0.963 0.926 0.970 
+ 555 0.689 0.041 0.544 0.000 0.000 0.000 0.673 0.963 0.927 0.970 
+ 556 0.690 0.025 0.556 0.000 0.000 0.000 0.674 0.963 0.927 0.969 
+ 557 0.691 0.015 0.565 0.000 0.000 0.000 0.674 0.963 0.928 0.968 
+ 558 0.691 0.009 0.570 0.000 0.000 0.000 0.675 0.963 0.928 0.968 
+ 559 0.693 0.006 0.575 0.000 0.000 0.000 0.678 0.963 0.929 0.967 
+ 560 0.695 0.003 0.578 0.000 0.000 0.000 0.680 0.963 0.929 0.966 
+ 561 0.697 0.002 0.582 0.000 0.000 0.000 0.682 0.963 0.930 0.965 
+ 562 0.699 0.002 0.584 0.000 0.000 0.000 0.683 0.963 0.930 0.964 
+ 563 0.701 0.001 0.586 0.000 0.000 0.000 0.685 0.963 0.930 0.963 
+ 564 0.703 0.001 0.588 0.000 0.000 0.000 0.686 0.963 0.931 0.962 
+ 565 0.705 0.001 0.590 0.000 0.000 0.000 0.688 0.964 0.931 0.961 
+ 566 0.707 0.001 0.591 0.000 0.000 0.000 0.690 0.964 0.932 0.961 
+ 567 0.709 0.000 0.592 0.000 0.000 0.000 0.692 0.964 0.933 0.960 
+ 568 0.710 0.000 0.592 0.000 0.000 0.000 0.695 0.964 0.933 0.958 
+ 569 0.712 0.000 0.591 0.000 0.000 0.000 0.696 0.964 0.933 0.957 
+ 570 0.714 0.000 0.591 0.000 0.000 0.000 0.698 0.964 0.934 0.956 
+ 571 0.716 0.000 0.589 0.000 0.000 0.000 0.700 0.964 0.934 0.955 
+ 572 0.717 0.000 0.586 0.000 0.000 0.000 0.700 0.964 0.935 0.954 
+ 573 0.718 0.000 0.583 0.000 0.000 0.000 0.701 0.964 0.935 0.953 
+ 574 0.719 0.000 0.581 0.000 0.000 0.000 0.702 0.964 0.936 0.952 
+ 575 0.721 0.000 0.582 0.000 0.000 0.000 0.704 0.964 0.936 0.952 
+ 576 0.724 0.000 0.586 0.000 0.000 0.000 0.707 0.965 0.937 0.952 
+ 577 0.726 0.000 0.592 0.000 0.000 0.000 0.709 0.965 0.937 0.952 
+ 578 0.729 0.000 0.599 0.000 0.000 0.000 0.712 0.965 0.938 0.953 
+ 579 0.732 0.000 0.606 0.000 0.000 0.000 0.715 0.965 0.938 0.954 
+ 580 0.735 0.000 0.612 0.000 0.000 0.000 0.719 0.965 0.938 0.955 
+ 581 0.738 0.000 0.615 0.000 0.000 0.000 0.722 0.965 0.939 0.957 
+ 582 0.741 0.000 0.617 0.000 0.000 0.000 0.725 0.965 0.939 0.958 
+ 583 0.744 0.000 0.617 0.000 0.000 0.000 0.727 0.965 0.940 0.959 
+ 584 0.746 0.000 0.616 0.000 0.000 0.000 0.728 0.965 0.940 0.960 
+ 585 0.748 0.000 0.614 0.000 0.000 0.000 0.729 0.965 0.940 0.961 
+ 586 0.750 0.000 0.611 0.000 0.000 0.000 0.729 0.965 0.941 0.961 
+ 587 0.752 0.000 0.609 0.000 0.000 0.000 0.730 0.965 0.941 0.961 
+ 588 0.754 0.000 0.609 0.000 0.000 0.000 0.731 0.966 0.942 0.960 
+ 589 0.752 0.000 0.610 0.000 0.000 0.000 0.731 0.966 0.942 0.957 
+ 590 0.754 0.000 0.615 0.000 0.000 0.000 0.733 0.966 0.942 0.957 
+ 591 0.758 0.000 0.621 0.000 0.000 0.000 0.738 0.966 0.943 0.958 
+ 592 0.759 0.000 0.623 0.000 0.000 0.000 0.740 0.966 0.943 0.957 
+ 593 0.762 0.000 0.623 0.000 0.000 0.000 0.742 0.966 0.944 0.957 
+ 594 0.764 0.000 0.621 0.000 0.000 0.000 0.742 0.966 0.944 0.957 
+ 595 0.766 0.000 0.621 0.000 0.000 0.000 0.742 0.966 0.944 0.955 
+ 596 0.769 0.000 0.624 0.000 0.000 0.000 0.744 0.966 0.945 0.956 
+ 597 0.770 0.000 0.628 0.000 0.000 0.000 0.743 0.966 0.945 0.956 
+ 598 0.772 0.000 0.633 0.000 0.000 0.000 0.744 0.966 0.945 0.956 
+ 599 0.774 0.000 0.638 0.000 0.000 0.000 0.747 0.966 0.946 0.956 
+ 600 0.776 0.000 0.641 0.000 0.000 0.000 0.751 0.966 0.946 0.956 
+ 601 0.778 0.000 0.642 0.000 0.000 0.000 0.755 0.967 0.947 0.956 
+ 602 0.779 0.000 0.644 0.000 0.000 0.000 0.758 0.967 0.947 0.956 
+ 603 0.781 0.000 0.647 0.000 0.000 0.000 0.761 0.967 0.947 0.956 
+ 604 0.784 0.000 0.649 0.000 0.000 0.000 0.764 0.967 0.948 0.956 
+ 605 0.786 0.000 0.651 0.000 0.000 0.000 0.765 0.967 0.948 0.956 
+ 606 0.788 0.000 0.652 0.000 0.000 0.000 0.766 0.967 0.948 0.957 
+ 607 0.790 0.000 0.653 0.000 0.000 0.000 0.766 0.967 0.949 0.957 
+ 608 0.792 0.000 0.654 0.000 0.000 0.000 0.768 0.967 0.949 0.958 
+ 609 0.795 0.000 0.655 0.000 0.000 0.000 0.771 0.967 0.949 0.959 
+ 610 0.797 0.000 0.655 0.000 0.000 0.000 0.775 0.967 0.950 0.959 
+ 611 0.799 0.000 0.656 0.000 0.000 0.000 0.779 0.967 0.950 0.960 
+ 612 0.801 0.000 0.656 0.000 0.000 0.000 0.782 0.967 0.950 0.961 
+ 613 0.804 0.000 0.657 0.000 0.000 0.000 0.785 0.967 0.951 0.961 
+ 614 0.806 0.000 0.656 0.000 0.000 0.000 0.787 0.968 0.951 0.962 
+ 615 0.807 0.000 0.653 0.000 0.000 0.000 0.788 0.968 0.951 0.962 
+ 616 0.808 0.000 0.648 0.000 0.000 0.000 0.789 0.968 0.952 0.963 
+ 617 0.810 0.000 0.643 0.000 0.000 0.000 0.789 0.968 0.952 0.963 
+ 618 0.812 0.000 0.640 0.000 0.000 0.000 0.791 0.968 0.952 0.964 
+ 619 0.814 0.000 0.640 0.000 0.000 0.000 0.792 0.968 0.953 0.964 
+ 620 0.817 0.000 0.642 0.000 0.000 0.000 0.794 0.968 0.953 0.964 
+ 621 0.820 0.000 0.645 0.000 0.000 0.000 0.797 0.968 0.953 0.964 
+ 622 0.823 0.000 0.648 0.000 0.000 0.000 0.800 0.968 0.953 0.964 
+ 623 0.824 0.000 0.647 0.000 0.000 0.000 0.802 0.968 0.954 0.964 
+ 624 0.825 0.000 0.646 0.000 0.000 0.000 0.804 0.968 0.954 0.964 
+ 625 0.825 0.000 0.646 0.000 0.000 0.000 0.806 0.968 0.954 0.964 
+ 626 0.826 0.000 0.648 0.000 0.000 0.000 0.808 0.968 0.955 0.964 
+ 627 0.828 0.000 0.652 0.000 0.000 0.000 0.810 0.968 0.955 0.964 
+ 628 0.808 0.000 0.641 0.000 0.000 0.000 0.791 0.969 0.955 0.939 
+ 629 0.823 0.000 0.655 0.000 0.000 0.000 0.805 0.969 0.955 0.954 
+ 630 0.823 0.000 0.657 0.000 0.000 0.000 0.804 0.969 0.956 0.953 
+ 631 0.832 0.000 0.662 0.000 0.000 0.000 0.811 0.969 0.956 0.960 
+ 632 0.836 0.000 0.662 0.000 0.000 0.000 0.814 0.969 0.956 0.963 
+ 633 0.840 0.000 0.660 0.000 0.000 0.000 0.817 0.969 0.957 0.966 
+ 634 0.843 0.000 0.660 0.000 0.000 0.000 0.821 0.969 0.957 0.967 
+ 635 0.845 0.000 0.660 0.000 0.000 0.000 0.824 0.969 0.957 0.968 
+ 636 0.847 0.000 0.663 0.000 0.000 0.000 0.828 0.969 0.957 0.970 
+ 637 0.850 0.000 0.668 0.000 0.000 0.000 0.831 0.969 0.958 0.971 
+ 638 0.852 0.000 0.673 0.000 0.000 0.000 0.835 0.969 0.958 0.972 
+ 639 0.855 0.000 0.678 0.000 0.000 0.000 0.838 0.969 0.958 0.973 
+ 640 0.857 0.000 0.681 0.000 0.000 0.000 0.838 0.969 0.958 0.973 
+ 641 0.859 0.000 0.684 0.000 0.000 0.000 0.838 0.969 0.959 0.974 
+ 642 0.860 0.000 0.685 0.000 0.000 0.000 0.836 0.969 0.959 0.975 
+ 643 0.862 0.000 0.686 0.000 0.000 0.000 0.835 0.970 0.959 0.975 
+ 644 0.865 0.000 0.687 0.000 0.000 0.000 0.835 0.970 0.959 0.976 
+ 645 0.866 0.000 0.686 0.000 0.000 0.000 0.835 0.970 0.960 0.976 
+ 646 0.866 0.000 0.685 0.000 0.000 0.000 0.836 0.970 0.960 0.976 
+ 647 0.867 0.000 0.684 0.000 0.000 0.000 0.838 0.970 0.960 0.975 
+ 648 0.867 0.000 0.683 0.000 0.000 0.000 0.842 0.970 0.960 0.973 
+ 649 0.869 0.000 0.683 0.000 0.000 0.000 0.846 0.970 0.961 0.974 
+ 650 0.873 0.000 0.685 0.000 0.000 0.000 0.852 0.970 0.961 0.977 
+ 651 0.875 0.000 0.686 0.000 0.000 0.000 0.856 0.970 0.961 0.978 
+ 652 0.874 0.000 0.684 0.000 0.000 0.000 0.854 0.970 0.961 0.975 
+ 653 0.879 0.000 0.686 0.000 0.000 0.000 0.858 0.970 0.962 0.978 
+ 654 0.881 0.000 0.687 0.000 0.000 0.000 0.858 0.970 0.962 0.979 
+ 655 0.880 0.000 0.684 0.000 0.000 0.000 0.854 0.970 0.962 0.977 
+ 656 0.882 0.000 0.684 0.000 0.000 0.000 0.853 0.970 0.962 0.979 
+ 657 0.883 0.000 0.682 0.000 0.000 0.000 0.852 0.970 0.963 0.980 
+ 658 0.885 0.000 0.682 0.000 0.000 0.000 0.854 0.970 0.963 0.980 
+ 659 0.887 0.000 0.681 0.000 0.000 0.000 0.857 0.971 0.963 0.981 
+ 660 0.889 0.000 0.679 0.000 0.000 0.000 0.861 0.971 0.963 0.982 
+ 661 0.892 0.000 0.677 0.000 0.000 0.000 0.866 0.971 0.964 0.982 
+ 662 0.894 0.000 0.675 0.000 0.000 0.000 0.871 0.971 0.964 0.983 
+ 663 0.895 0.000 0.672 0.000 0.000 0.000 0.875 0.971 0.964 0.983 
+ 664 0.896 0.000 0.669 0.000 0.000 0.000 0.878 0.971 0.964 0.984 
+ 665 0.897 0.000 0.666 0.001 0.000 0.000 0.879 0.971 0.964 0.984 
+ 666 0.898 0.000 0.664 0.001 0.000 0.000 0.878 0.971 0.965 0.984 
+ 667 0.899 0.000 0.663 0.001 0.000 0.000 0.876 0.971 0.965 0.985 
+ 668 0.900 0.000 0.663 0.001 0.000 0.000 0.875 0.971 0.965 0.985 
+ 669 0.902 0.000 0.663 0.001 0.000 0.000 0.873 0.971 0.965 0.985 
+ 670 0.903 0.000 0.663 0.001 0.000 0.000 0.872 0.971 0.965 0.986 
+ 671 0.904 0.000 0.662 0.001 0.000 0.000 0.872 0.971 0.966 0.986 
+ 672 0.906 0.000 0.662 0.002 0.000 0.000 0.873 0.971 0.966 0.986 
+ 673 0.906 0.000 0.660 0.002 0.000 0.000 0.875 0.971 0.966 0.987 
+ 674 0.907 0.000 0.658 0.003 0.000 0.000 0.879 0.971 0.966 0.987 
+ 675 0.908 0.000 0.655 0.004 0.000 0.000 0.883 0.971 0.966 0.987 
+ 676 0.910 0.000 0.652 0.005 0.000 0.000 0.888 0.972 0.967 0.988 
+ 677 0.911 0.000 0.649 0.007 0.000 0.000 0.892 0.972 0.967 0.988 
+ 678 0.912 0.000 0.644 0.009 0.000 0.000 0.896 0.972 0.967 0.988 
+ 679 0.914 0.000 0.639 0.012 0.000 0.000 0.898 0.972 0.967 0.988 
+ 680 0.916 0.000 0.633 0.016 0.000 0.000 0.900 0.972 0.967 0.989 
+ 681 0.917 0.000 0.626 0.022 0.000 0.000 0.899 0.972 0.968 0.989 
+ 682 0.918 0.000 0.617 0.029 0.000 0.000 0.898 0.972 0.968 0.989 
+ 683 0.919 0.000 0.608 0.039 0.000 0.000 0.896 0.972 0.968 0.989 
+ 684 0.920 0.000 0.595 0.056 0.000 0.000 0.895 0.972 0.968 0.989 
+ 685 0.921 0.000 0.579 0.084 0.000 0.000 0.894 0.972 0.968 0.989 
+ 686 0.921 0.000 0.556 0.133 0.000 0.000 0.894 0.972 0.969 0.989 
+ 687 0.750 0.000 0.427 0.169 0.000 0.000 0.728 0.972 0.969 0.805 
+ 688 0.813 0.000 0.428 0.264 0.000 0.000 0.791 0.972 0.969 0.873 
+ 689 0.825 0.000 0.391 0.350 0.000 0.000 0.804 0.972 0.969 0.885 
+ 690 0.835 0.000 0.346 0.426 0.000 0.000 0.817 0.972 0.969 0.895 
+ 691 0.870 0.000 0.305 0.512 0.000 0.000 0.853 0.972 0.969 0.933 
+ 692 0.888 0.000 0.255 0.591 0.000 0.000 0.873 0.972 0.970 0.953 
+ 693 0.901 0.000 0.204 0.670 0.000 0.000 0.888 0.973 0.970 0.967 
+ 694 0.908 0.000 0.156 0.737 0.000 0.000 0.895 0.973 0.970 0.974 
+ 695 0.917 0.000 0.116 0.792 0.000 0.000 0.903 0.973 0.970 0.982 
+ 696 0.918 0.000 0.084 0.821 0.000 0.000 0.903 0.973 0.970 0.981 
+ 697 0.929 0.000 0.060 0.843 0.000 0.000 0.912 0.973 0.970 0.990 
+ 698 0.930 0.000 0.042 0.848 0.000 0.000 0.911 0.973 0.971 0.990 
+ 699 0.926 0.000 0.029 0.846 0.000 0.000 0.905 0.973 0.971 0.986 
+ 700 0.926 0.000 0.021 0.848 0.000 0.000 0.904 0.973 0.971 0.986 
+ 701 0.925 0.000 0.015 0.847 0.000 0.000 0.902 0.973 0.971 0.986 
+ 702 0.926 0.000 0.011 0.847 0.000 0.000 0.903 0.973 0.971 0.987 
+ 703 0.926 0.000 0.008 0.845 0.000 0.000 0.904 0.973 0.971 0.987 
+ 704 0.930 0.000 0.006 0.848 0.000 0.000 0.908 0.973 0.972 0.989 
+ 705 0.931 0.000 0.005 0.849 0.000 0.000 0.911 0.973 0.972 0.989 
+ 706 0.934 0.000 0.004 0.852 0.000 0.000 0.914 0.973 0.972 0.991 
+ 707 0.935 0.000 0.003 0.853 0.000 0.000 0.916 0.973 0.972 0.991 
+ 708 0.936 0.000 0.002 0.851 0.000 0.000 0.917 0.973 0.972 0.991 
+ 709 0.937 0.000 0.002 0.849 0.000 0.000 0.919 0.974 0.972 0.992 
+ 710 0.937 0.000 0.001 0.847 0.000 0.000 0.918 0.974 0.973 0.992 
+ 711 0.938 0.000 0.001 0.847 0.000 0.000 0.917 0.974 0.973 0.992 
+ 712 0.939 0.000 0.001 0.849 0.000 0.000 0.916 0.974 0.973 0.993 
+ 713 0.938 0.000 0.001 0.852 0.000 0.000 0.914 0.974 0.973 0.993 
+ 714 0.938 0.000 0.000 0.855 0.000 0.000 0.912 0.974 0.973 0.992 
+ 715 0.936 0.000 0.000 0.857 0.000 0.000 0.910 0.974 0.973 0.991 
+ 716 0.935 0.000 0.000 0.859 0.000 0.000 0.908 0.974 0.974 0.991 
+ 717 0.917 0.000 0.000 0.844 0.000 0.000 0.891 0.974 0.974 0.972 
+ 718 0.904 0.000 0.000 0.833 0.000 0.000 0.879 0.974 0.974 0.958 
+ 719 0.885 0.000 0.000 0.816 0.000 0.000 0.862 0.974 0.974 0.938 
+ 720 0.894 0.000 0.000 0.825 0.000 0.000 0.872 0.974 0.974 0.946 
+ 721 0.912 0.000 0.000 0.842 0.000 0.000 0.890 0.974 0.974 0.963 
+ 722 0.936 0.000 0.000 0.863 0.000 0.000 0.914 0.974 0.974 0.988 
+ 723 0.920 0.000 0.000 0.846 0.000 0.000 0.898 0.974 0.975 0.971 
+ 724 0.906 0.000 0.000 0.833 0.000 0.000 0.886 0.974 0.975 0.959 
+ 725 0.907 0.000 0.000 0.833 0.000 0.000 0.885 0.975 0.975 0.959 
+ 726 0.917 0.000 0.000 0.842 0.000 0.000 0.894 0.975 0.975 0.970 
+ 727 0.910 0.000 0.000 0.835 0.000 0.000 0.887 0.975 0.975 0.965 
+ 728 0.911 0.000 0.000 0.833 0.000 0.000 0.887 0.975 0.975 0.966 
+ 729 0.914 0.000 0.000 0.831 0.000 0.000 0.888 0.975 0.975 0.969 
+ 730 0.925 0.000 0.000 0.838 0.000 0.000 0.899 0.975 0.975 0.981 
+ 731 0.916 0.000 0.000 0.828 0.000 0.000 0.889 0.975 0.976 0.970 
+ 732 0.927 0.000 0.000 0.838 0.000 0.000 0.900 0.975 0.976 0.982 
+ 733 0.935 0.000 0.000 0.846 0.000 0.000 0.908 0.975 0.976 0.989 
+ 734 0.937 0.000 0.000 0.850 0.000 0.000 0.910 0.975 0.976 0.990 
+ 735 0.938 0.000 0.000 0.853 0.000 0.000 0.912 0.975 0.976 0.990 
+ 736 0.939 0.000 0.000 0.857 0.000 0.000 0.915 0.975 0.976 0.991 
+ 737 0.940 0.000 0.000 0.860 0.000 0.000 0.916 0.975 0.976 0.990 
+ 738 0.944 0.000 0.000 0.864 0.000 0.000 0.921 0.975 0.977 0.994 
+ 739 0.943 0.000 0.000 0.864 0.000 0.000 0.920 0.975 0.977 0.993 
+ 740 0.944 0.000 0.000 0.865 0.000 0.000 0.922 0.975 0.977 0.995 
+ 741 0.944 0.000 0.000 0.865 0.000 0.000 0.922 0.975 0.977 0.995 
+ 742 0.945 0.000 0.000 0.866 0.000 0.000 0.922 0.976 0.977 0.996 
+ 743 0.944 0.000 0.000 0.865 0.000 0.000 0.921 0.976 0.977 0.996 
+ 744 0.944 0.000 0.000 0.865 0.000 0.000 0.920 0.976 0.977 0.996 
+ 745 0.944 0.000 0.000 0.865 0.000 0.000 0.920 0.976 0.977 0.996 
+ 746 0.945 0.000 0.000 0.865 0.000 0.000 0.920 0.976 0.978 0.996 
+ 747 0.945 0.000 0.000 0.865 0.000 0.000 0.920 0.976 0.978 0.996 
+ 748 0.946 0.000 0.000 0.865 0.000 0.000 0.921 0.976 0.978 0.996 
+ 749 0.947 0.000 0.000 0.867 0.000 0.000 0.922 0.976 0.978 0.996 
+ 750 0.948 0.000 0.000 0.868 0.000 0.000 0.923 0.976 0.978 0.997 
+ 751 0.948 0.000 0.000 0.868 0.000 0.000 0.924 0.976 0.978 0.997 
+ 752 0.949 0.000 0.000 0.869 0.000 0.000 0.924 0.976 0.978 0.997 
+ 753 0.949 0.000 0.000 0.868 0.000 0.000 0.925 0.976 0.978 0.997 
+ 754 0.948 0.000 0.000 0.868 0.000 0.000 0.925 0.976 0.978 0.997 
+ 755 0.948 0.000 0.000 0.867 0.000 0.000 0.925 0.976 0.979 0.997 
+ 756 0.948 0.000 0.000 0.866 0.000 0.000 0.926 0.976 0.979 0.998 
+ 757 0.947 0.000 0.000 0.864 0.000 0.000 0.925 0.976 0.979 0.998 
+ 758 0.946 0.000 0.000 0.863 0.000 0.000 0.925 0.976 0.979 0.998 
+ 759 0.943 0.000 0.000 0.860 0.000 0.000 0.923 0.976 0.979 0.995 
+ 760 0.448 0.000 0.000 0.408 0.000 0.000 0.438 0.977 0.979 0.472 
+ 761 0.364 0.000 0.000 0.331 0.000 0.000 0.356 0.977 0.979 0.383 
+ 762 0.719 0.000 0.000 0.655 0.000 0.000 0.703 0.977 0.979 0.757 
+ 763 0.501 0.000 0.000 0.456 0.000 0.000 0.489 0.977 0.979 0.528 
+ 764 0.617 0.000 0.000 0.562 0.000 0.000 0.602 0.977 0.980 0.650 
+ 765 0.702 0.000 0.000 0.640 0.000 0.000 0.684 0.977 0.980 0.741 
+ 766 0.800 0.000 0.000 0.730 0.000 0.000 0.778 0.977 0.980 0.844 
+ 767 0.857 0.000 0.000 0.783 0.000 0.000 0.832 0.977 0.980 0.905 
+ 768 0.911 0.000 0.000 0.833 0.000 0.000 0.883 0.977 0.980 0.962 
+ 769 0.923 0.000 0.000 0.845 0.000 0.000 0.893 0.977 0.980 0.975 
+ 770 0.938 0.000 0.000 0.859 0.000 0.000 0.906 0.977 0.980 0.989 
+ 771 0.943 0.000 0.000 0.865 0.000 0.000 0.910 0.977 0.980 0.995 
+ 772 0.944 0.000 0.000 0.865 0.000 0.000 0.910 0.977 0.980 0.996 
+ 773 0.943 0.000 0.000 0.863 0.000 0.000 0.909 0.977 0.980 0.997 
+ 774 0.942 0.000 0.000 0.860 0.000 0.000 0.910 0.977 0.981 0.997 
+ 775 0.942 0.000 0.000 0.858 0.000 0.000 0.911 0.977 0.981 0.997 
+ 776 0.943 0.000 0.000 0.855 0.000 0.000 0.913 0.977 0.981 0.997 
+ 777 0.943 0.000 0.000 0.853 0.000 0.000 0.915 0.977 0.981 0.997 
+ 778 0.943 0.000 0.000 0.851 0.000 0.000 0.917 0.977 0.981 0.997 
+ 779 0.943 0.000 0.000 0.848 0.000 0.000 0.918 0.978 0.981 0.997 
+ 780 0.943 0.000 0.000 0.844 0.000 0.000 0.919 0.978 0.981 0.997 
+ 781 0.942 0.000 0.000 0.842 0.000 0.000 0.919 0.978 0.981 0.997 
+ 782 0.942 0.000 0.000 0.841 0.000 0.000 0.918 0.978 0.981 0.998 
+ 783 0.942 0.000 0.000 0.840 0.000 0.000 0.917 0.978 0.982 0.998 
+ 784 0.941 0.000 0.000 0.838 0.000 0.000 0.915 0.978 0.982 0.998 
+ 785 0.940 0.000 0.000 0.836 0.001 0.000 0.913 0.978 0.982 0.998 
+ 786 0.939 0.000 0.000 0.833 0.001 0.000 0.911 0.978 0.982 0.997 
+ 787 0.937 0.000 0.000 0.830 0.001 0.000 0.908 0.978 0.982 0.996 
+ 788 0.937 0.000 0.000 0.828 0.001 0.000 0.906 0.978 0.982 0.996 
+ 789 0.936 0.000 0.000 0.824 0.001 0.000 0.905 0.978 0.982 0.995 
+ 790 0.933 0.000 0.000 0.820 0.001 0.000 0.904 0.978 0.982 0.992 
+ 791 0.934 0.000 0.000 0.822 0.001 0.000 0.907 0.978 0.982 0.995 
+ 792 0.934 0.000 0.000 0.824 0.001 0.000 0.908 0.978 0.982 0.995 
+ 793 0.933 0.000 0.000 0.827 0.001 0.000 0.909 0.978 0.982 0.995 
+ 794 0.936 0.000 0.000 0.834 0.002 0.000 0.913 0.978 0.982 0.998 
+ 795 0.937 0.000 0.000 0.838 0.002 0.000 0.915 0.978 0.983 0.997 
+ 796 0.933 0.000 0.000 0.838 0.002 0.000 0.912 0.978 0.983 0.993 
+ 797 0.935 0.000 0.000 0.843 0.003 0.000 0.914 0.978 0.983 0.994 
+ 798 0.938 0.000 0.000 0.846 0.004 0.000 0.916 0.978 0.983 0.997 
+ 799 0.936 0.000 0.000 0.844 0.005 0.000 0.914 0.978 0.983 0.996 
+ 800 0.933 0.000 0.000 0.841 0.006 0.000 0.911 0.979 0.983 0.995 
+ 801 0.931 0.000 0.000 0.838 0.007 0.000 0.907 0.979 0.983 0.995 
+ 802 0.930 0.000 0.000 0.835 0.008 0.000 0.903 0.979 0.983 0.994 
+ 803 0.930 0.000 0.000 0.834 0.009 0.000 0.900 0.979 0.983 0.994 
+ 804 0.932 0.000 0.000 0.832 0.012 0.000 0.895 0.979 0.983 0.995 
+ 805 0.933 0.000 0.000 0.830 0.015 0.000 0.884 0.979 0.983 0.996 
+ 806 0.935 0.000 0.000 0.828 0.019 0.000 0.868 0.979 0.983 0.997 
+ 807 0.934 0.000 0.000 0.824 0.025 0.000 0.840 0.979 0.984 0.997 
+ 808 0.934 0.000 0.000 0.821 0.034 0.000 0.804 0.979 0.984 0.997 
+ 809 0.932 0.000 0.000 0.817 0.045 0.000 0.758 0.979 0.984 0.996 
+ 810 0.930 0.000 0.000 0.813 0.060 0.000 0.704 0.979 0.984 0.994 
+ 811 0.930 0.000 0.000 0.810 0.079 0.000 0.644 0.979 0.984 0.994 
+ 812 0.925 0.000 0.000 0.804 0.101 0.000 0.578 0.979 0.984 0.990 
+ 813 0.920 0.000 0.000 0.798 0.129 0.000 0.512 0.979 0.984 0.986 
+ 814 0.904 0.000 0.000 0.780 0.160 0.000 0.442 0.979 0.984 0.969 
+ 815 0.902 0.000 0.000 0.767 0.203 0.000 0.384 0.979 0.984 0.968 
+ 816 0.885 0.000 0.000 0.728 0.252 0.000 0.325 0.979 0.984 0.949 
+ 817 0.887 0.000 0.000 0.684 0.318 0.000 0.280 0.979 0.984 0.953 
+ 818 0.883 0.000 0.000 0.609 0.397 0.000 0.238 0.979 0.984 0.950 
+ 819 0.902 0.000 0.000 0.523 0.499 0.000 0.206 0.979 0.985 0.970 
+ 820 0.892 0.000 0.000 0.408 0.588 0.000 0.172 0.979 0.985 0.959 
+ 821 0.921 0.000 0.000 0.313 0.696 0.000 0.149 0.979 0.985 0.990 
+ 822 0.916 0.000 0.000 0.221 0.761 0.000 0.123 0.979 0.985 0.984 
+ 823 0.851 0.000 0.000 0.142 0.750 0.000 0.094 0.980 0.985 0.914 
+ 824 0.913 0.000 0.000 0.104 0.833 0.000 0.082 0.980 0.985 0.982 
+ 825 0.914 0.000 0.000 0.071 0.849 0.000 0.066 0.980 0.985 0.984 
+ 826 0.907 0.000 0.000 0.047 0.850 0.000 0.053 0.980 0.985 0.978 
+ 827 0.916 0.000 0.000 0.033 0.863 0.000 0.042 0.980 0.985 0.988 
+ 828 0.887 0.000 0.000 0.021 0.839 0.000 0.033 0.980 0.985 0.957 
+ 829 0.906 0.000 0.000 0.015 0.860 0.000 0.027 0.980 0.985 0.979 
+ 830 0.904 0.000 0.000 0.010 0.858 0.000 0.021 0.980 0.985 0.978 
+ 831 0.904 0.000 0.000 0.007 0.857 0.000 0.017 0.980 0.985 0.979 
+ 832 0.895 0.000 0.000 0.005 0.845 0.000 0.014 0.980 0.985 0.970 
+ 833 0.915 0.000 0.000 0.004 0.862 0.000 0.012 0.980 0.986 0.991 
+ 834 0.909 0.000 0.000 0.003 0.857 0.000 0.010 0.980 0.986 0.986 
+ 835 0.919 0.000 0.000 0.002 0.867 0.000 0.008 0.980 0.986 0.996 
+ 836 0.915 0.000 0.000 0.002 0.867 0.000 0.007 0.980 0.986 0.990 
+ 837 0.921 0.000 0.000 0.001 0.877 0.000 0.006 0.980 0.986 0.996 
+ 838 0.920 0.000 0.000 0.001 0.879 0.000 0.006 0.980 0.986 0.995 
+ 839 0.920 0.000 0.000 0.001 0.880 0.000 0.005 0.980 0.986 0.997 
+ 840 0.920 0.000 0.000 0.001 0.880 0.000 0.004 0.980 0.986 0.997 
+ 841 0.918 0.000 0.000 0.001 0.876 0.000 0.004 0.980 0.986 0.996 
+ 842 0.917 0.000 0.000 0.001 0.873 0.000 0.004 0.980 0.986 0.997 
+ 843 0.917 0.000 0.000 0.001 0.871 0.000 0.004 0.980 0.986 0.998 
+ 844 0.915 0.000 0.000 0.000 0.869 0.000 0.003 0.980 0.986 0.997 
+ 845 0.915 0.000 0.000 0.000 0.869 0.000 0.003 0.980 0.986 0.999 
+ 846 0.914 0.000 0.000 0.000 0.868 0.000 0.003 0.980 0.986 0.998 
+ 847 0.913 0.000 0.000 0.000 0.868 0.000 0.003 0.981 0.986 0.999 
+ 848 0.911 0.000 0.000 0.000 0.867 0.000 0.002 0.981 0.987 0.998 
+ 849 0.911 0.000 0.000 0.000 0.866 0.000 0.002 0.981 0.987 0.998 
+ 850 0.910 0.000 0.000 0.000 0.865 0.000 0.002 0.981 0.987 0.998 
+ 851 0.909 0.000 0.000 0.000 0.863 0.000 0.002 0.981 0.987 0.997 
+ 852 0.909 0.000 0.000 0.000 0.861 0.000 0.001 0.981 0.987 0.998 
+ 853 0.909 0.000 0.000 0.000 0.858 0.000 0.001 0.981 0.987 0.998 
+ 854 0.908 0.000 0.000 0.000 0.855 0.000 0.001 0.981 0.987 0.998 
+ 855 0.907 0.000 0.000 0.000 0.854 0.000 0.001 0.981 0.987 0.999 
+ 856 0.906 0.000 0.000 0.000 0.852 0.000 0.001 0.981 0.987 0.998 
+ 857 0.904 0.000 0.000 0.000 0.850 0.000 0.001 0.981 0.987 0.999 
+ 858 0.902 0.000 0.000 0.000 0.848 0.000 0.001 0.981 0.987 0.999 
+ 859 0.901 0.000 0.000 0.000 0.848 0.000 0.001 0.981 0.987 0.999 
+ 860 0.900 0.000 0.000 0.000 0.849 0.000 0.000 0.981 0.987 0.999 
+ 861 0.900 0.000 0.000 0.000 0.850 0.000 0.000 0.981 0.987 0.999 
+ 862 0.899 0.000 0.000 0.000 0.851 0.000 0.000 0.981 0.987 0.999 
+ 863 0.898 0.000 0.000 0.000 0.850 0.000 0.000 0.981 0.987 0.999 
+ 864 0.897 0.000 0.000 0.000 0.849 0.000 0.000 0.981 0.988 0.999 
+ 865 0.896 0.000 0.000 0.000 0.849 0.000 0.000 0.981 0.988 0.999 
+ 866 0.896 0.000 0.000 0.000 0.848 0.000 0.000 0.981 0.988 0.999 
+ 867 0.895 0.000 0.000 0.000 0.846 0.000 0.000 0.981 0.988 0.999 
+ 868 0.893 0.000 0.000 0.000 0.845 0.000 0.000 0.981 0.988 1.000 
+ 869 0.892 0.000 0.000 0.000 0.843 0.000 0.000 0.981 0.988 1.000 
+ 870 0.891 0.000 0.000 0.000 0.840 0.000 0.000 0.981 0.988 1.000 
+ 871 0.889 0.000 0.000 0.000 0.839 0.000 0.000 0.981 0.988 1.000 
+ 872 0.887 0.000 0.000 0.000 0.837 0.000 0.000 0.981 0.988 1.000 
+ 873 0.885 0.000 0.000 0.000 0.835 0.000 0.000 0.981 0.988 1.000 
+ 874 0.883 0.000 0.000 0.000 0.833 0.000 0.000 0.982 0.988 1.000 
+ 875 0.881 0.000 0.000 0.000 0.832 0.000 0.000 0.982 0.988 1.000 
+ 876 0.878 0.000 0.000 0.000 0.831 0.000 0.000 0.982 0.988 1.000 
+ 877 0.877 0.000 0.000 0.000 0.829 0.000 0.000 0.982 0.988 1.000 
+ 878 0.874 0.000 0.000 0.000 0.827 0.000 0.000 0.982 0.988 1.000 
+ 879 0.872 0.000 0.000 0.000 0.824 0.000 0.000 0.982 0.988 1.000 
+ 880 0.869 0.000 0.000 0.000 0.820 0.000 0.000 0.982 0.988 1.000 
+ 881 0.866 0.000 0.000 0.000 0.816 0.000 0.000 0.982 0.988 0.999 
+ 882 0.863 0.000 0.000 0.000 0.810 0.000 0.000 0.982 0.989 0.999 
+ 883 0.861 0.000 0.000 0.000 0.806 0.000 0.000 0.982 0.989 0.999 
+ 884 0.859 0.000 0.000 0.000 0.801 0.000 0.000 0.982 0.989 0.999 
+ 885 0.857 0.000 0.000 0.000 0.796 0.000 0.000 0.982 0.989 0.999 
+ 886 0.854 0.000 0.000 0.000 0.792 0.000 0.000 0.982 0.989 0.998 
+ 887 0.851 0.000 0.000 0.000 0.790 0.000 0.000 0.982 0.989 0.999 
+ 888 0.846 0.000 0.000 0.000 0.787 0.000 0.000 0.982 0.989 0.998 
+ 889 0.844 0.000 0.000 0.000 0.786 0.000 0.000 0.982 0.989 1.000 
+ 890 0.839 0.000 0.000 0.000 0.783 0.000 0.000 0.982 0.989 0.998 
+ 891 0.838 0.000 0.000 0.000 0.783 0.000 0.000 0.982 0.989 0.999 
+ 892 0.836 0.000 0.000 0.000 0.781 0.000 0.000 0.982 0.989 0.997 
+ 893 0.830 0.000 0.000 0.000 0.777 0.000 0.000 0.982 0.989 0.993 
+ 894 0.825 0.000 0.000 0.000 0.773 0.000 0.000 0.982 0.989 0.990 
+ 895 0.817 0.000 0.000 0.000 0.764 0.000 0.000 0.982 0.989 0.984 
+ 896 0.801 0.000 0.000 0.000 0.747 0.000 0.000 0.982 0.989 0.968 
+ 897 0.778 0.000 0.000 0.000 0.723 0.001 0.000 0.982 0.989 0.943 
+ 898 0.786 0.000 0.000 0.000 0.727 0.001 0.000 0.982 0.989 0.956 
+ 899 0.729 0.000 0.000 0.000 0.671 0.001 0.000 0.982 0.989 0.890 
+ 900 0.783 0.000 0.000 0.000 0.719 0.001 0.000 0.982 0.989 0.960 
+ 901 0.760 0.000 0.000 0.000 0.697 0.002 0.000 0.982 0.989 0.934 
+ 902 0.773 0.000 0.000 0.000 0.710 0.002 0.000 0.983 0.990 0.955 
+ 903 0.752 0.000 0.000 0.000 0.691 0.002 0.000 0.983 0.990 0.934 
+ 904 0.793 0.000 0.000 0.000 0.730 0.002 0.000 0.983 0.990 0.990 
+ 905 0.785 0.000 0.000 0.000 0.725 0.002 0.000 0.983 0.990 0.985 
+ 906 0.770 0.000 0.000 0.000 0.714 0.003 0.000 0.983 0.990 0.972 
+ 907 0.738 0.000 0.000 0.000 0.687 0.003 0.000 0.983 0.990 0.936 
+ 908 0.738 0.000 0.000 0.000 0.688 0.003 0.000 0.983 0.990 0.940 
+ 909 0.744 0.000 0.000 0.000 0.694 0.005 0.000 0.983 0.990 0.952 
+ 910 0.731 0.000 0.000 0.000 0.683 0.006 0.000 0.983 0.990 0.941 
+ 911 0.740 0.000 0.000 0.000 0.691 0.009 0.000 0.983 0.990 0.959 
+ 912 0.731 0.000 0.000 0.000 0.680 0.015 0.000 0.983 0.990 0.952 
+ 913 0.720 0.000 0.000 0.000 0.666 0.024 0.000 0.983 0.990 0.943 
+ 914 0.711 0.000 0.000 0.000 0.653 0.040 0.000 0.983 0.990 0.937 
+ 915 0.723 0.000 0.000 0.000 0.659 0.066 0.000 0.983 0.990 0.960 
+ 916 0.694 0.000 0.000 0.000 0.625 0.098 0.000 0.983 0.990 0.927 
+ 917 0.725 0.000 0.000 0.000 0.642 0.152 0.000 0.983 0.990 0.975 
+ 918 0.686 0.000 0.000 0.000 0.592 0.199 0.000 0.983 0.990 0.930 
+ 919 0.711 0.000 0.000 0.000 0.590 0.271 0.000 0.983 0.990 0.971 
+ 920 0.705 0.000 0.000 0.000 0.549 0.335 0.000 0.983 0.990 0.970 
+ 921 0.711 0.000 0.000 0.000 0.504 0.403 0.000 0.983 0.990 0.986 
+ 922 0.693 0.000 0.000 0.000 0.429 0.451 0.000 0.983 0.990 0.969 
+ 923 0.699 0.000 0.000 0.000 0.361 0.506 0.000 0.983 0.990 0.984 
+ 924 0.687 0.000 0.000 0.000 0.283 0.539 0.000 0.983 0.990 0.976 
+ 925 0.677 0.000 0.000 0.000 0.214 0.565 0.000 0.983 0.990 0.970 
+ 926 0.675 0.000 0.000 0.000 0.158 0.591 0.000 0.983 0.991 0.976 
+ 927 0.679 0.000 0.000 0.000 0.116 0.615 0.000 0.983 0.991 0.988 
+ 928 0.642 0.000 0.000 0.000 0.079 0.597 0.000 0.983 0.991 0.943 
+ 929 0.635 0.000 0.000 0.000 0.057 0.601 0.000 0.983 0.991 0.941 
+ 930 0.595 0.000 0.000 0.000 0.039 0.570 0.000 0.983 0.991 0.890 
+ 931 0.562 0.000 0.000 0.000 0.028 0.543 0.000 0.983 0.991 0.849 
+ 932 0.516 0.000 0.000 0.000 0.019 0.501 0.000 0.983 0.991 0.788 
+ 933 0.499 0.000 0.000 0.000 0.014 0.486 0.000 0.983 0.991 0.771 
+ 934 0.445 0.000 0.000 0.000 0.010 0.435 0.000 0.984 0.991 0.696 
+ 935 0.473 0.000 0.000 0.000 0.008 0.464 0.000 0.984 0.991 0.751 
+ 936 0.409 0.000 0.000 0.000 0.006 0.401 0.000 0.984 0.991 0.657 
+ 937 0.442 0.000 0.000 0.000 0.005 0.435 0.000 0.984 0.991 0.720 
+ 938 0.447 0.000 0.000 0.000 0.004 0.441 0.000 0.984 0.991 0.739 
+ 939 0.520 0.000 0.000 0.000 0.004 0.513 0.000 0.984 0.991 0.870 
+ 940 0.536 0.000 0.000 0.000 0.004 0.529 0.000 0.984 0.991 0.910 
+ 941 0.504 0.000 0.000 0.000 0.003 0.498 0.000 0.984 0.991 0.868 
+ 942 0.505 0.000 0.000 0.000 0.002 0.499 0.000 0.984 0.991 0.883 
+ 943 0.437 0.000 0.000 0.000 0.002 0.431 0.000 0.984 0.991 0.774 
+ 944 0.425 0.000 0.000 0.000 0.002 0.419 0.000 0.984 0.991 0.763 
+ 945 0.478 0.000 0.000 0.000 0.001 0.471 0.000 0.984 0.991 0.868 
+ 946 0.393 0.000 0.000 0.000 0.001 0.386 0.000 0.984 0.991 0.722 
+ 947 0.468 0.000 0.000 0.000 0.001 0.459 0.000 0.984 0.991 0.868 
+ 948 0.412 0.000 0.000 0.000 0.001 0.404 0.000 0.984 0.991 0.773 
+ 949 0.498 0.000 0.000 0.000 0.001 0.487 0.000 0.984 0.991 0.943 
+ 950 0.358 0.000 0.000 0.000 0.000 0.349 0.000 0.984 0.991 0.685 
+ 951 0.493 0.000 0.000 0.000 0.001 0.480 0.000 0.984 0.992 0.952 
+ 952 0.397 0.000 0.000 0.000 0.000 0.386 0.000 0.984 0.992 0.775 
+ 953 0.435 0.000 0.000 0.000 0.000 0.422 0.000 0.984 0.992 0.858 
+ 954 0.448 0.000 0.000 0.000 0.000 0.435 0.000 0.984 0.992 0.895 
+ 955 0.426 0.000 0.000 0.000 0.000 0.413 0.000 0.984 0.992 0.860 
+ 956 0.415 0.000 0.000 0.000 0.000 0.402 0.000 0.984 0.992 0.847 
+ 957 0.400 0.000 0.000 0.000 0.000 0.388 0.000 0.984 0.992 0.827 
+ 958 0.425 0.000 0.000 0.000 0.000 0.412 0.000 0.984 0.992 0.889 
+ 959 0.409 0.000 0.000 0.000 0.000 0.395 0.000 0.984 0.992 0.866 
+ 960 0.414 0.000 0.000 0.000 0.000 0.401 0.000 0.984 0.992 0.889 
+ 961 0.414 0.000 0.000 0.000 0.000 0.401 0.000 0.984 0.992 0.900 
+ 962 0.407 0.000 0.000 0.000 0.000 0.394 0.000 0.984 0.992 0.895 
+ 963 0.412 0.000 0.000 0.000 0.000 0.399 0.000 0.984 0.992 0.920 
+ 964 0.399 0.000 0.000 0.000 0.000 0.386 0.000 0.984 0.992 0.904 
+ 965 0.399 0.000 0.000 0.000 0.000 0.387 0.000 0.984 0.992 0.918 
+ 966 0.394 0.000 0.000 0.000 0.000 0.382 0.000 0.984 0.992 0.920 
+ 967 0.393 0.000 0.000 0.000 0.000 0.381 0.000 0.984 0.992 0.931 
+ 968 0.400 0.000 0.000 0.000 0.000 0.388 0.000 0.985 0.992 0.962 
+ 969 0.402 0.000 0.000 0.000 0.000 0.390 0.000 0.985 0.992 0.982 
+ 970 0.390 0.000 0.000 0.000 0.000 0.378 0.000 0.985 0.992 0.967 
+ 971 0.391 0.000 0.000 0.000 0.000 0.380 0.000 0.985 0.992 0.988 
+ 972 0.379 0.000 0.000 0.000 0.000 0.368 0.000 0.985 0.992 0.974 
+ 973 0.368 0.000 0.000 0.000 0.000 0.358 0.000 0.985 0.992 0.963 
+ 974 0.358 0.000 0.000 0.000 0.000 0.349 0.000 0.985 0.992 0.955 
+ 975 0.349 0.000 0.000 0.000 0.000 0.341 0.000 0.985 0.992 0.947 
+ 976 0.345 0.000 0.000 0.000 0.000 0.337 0.000 0.985 0.992 0.953 
+ 977 0.343 0.000 0.000 0.000 0.000 0.335 0.000 0.985 0.992 0.966 
+ 978 0.335 0.000 0.000 0.000 0.000 0.327 0.000 0.985 0.992 0.962 
+ 979 0.334 0.000 0.000 0.000 0.000 0.326 0.000 0.985 0.992 0.975 
+ 980 0.323 0.000 0.000 0.000 0.000 0.315 0.000 0.985 0.993 0.961 
+ 981 0.325 0.000 0.000 0.000 0.000 0.318 0.000 0.985 0.993 0.989 
+ 982 0.318 0.000 0.000 0.000 0.000 0.311 0.000 0.985 0.993 0.987 
+ 983 0.308 0.000 0.000 0.000 0.000 0.302 0.000 0.985 0.993 0.978 
+ 984 0.307 0.000 0.000 0.000 0.000 0.301 0.000 0.985 0.993 0.997 
+ 985 0.298 0.000 0.000 0.000 0.000 0.292 0.000 0.985 0.993 0.984 
+ 986 0.295 0.000 0.000 0.000 0.000 0.290 0.000 0.985 0.993 0.998 
+ 987 0.287 0.000 0.000 0.000 0.000 0.282 0.000 0.985 0.993 0.996 
+ 988 0.278 0.000 0.000 0.000 0.000 0.274 0.000 0.985 0.993 0.995 
+ 989 0.272 0.000 0.000 0.000 0.000 0.268 0.000 0.985 0.993 0.999 
+ 990 0.264 0.000 0.000 0.000 0.000 0.260 0.000 0.985 0.993 0.996 
+ 991 0.259 0.000 0.000 0.000 0.000 0.255 0.000 0.985 0.993 0.998 
+ 992 0.253 0.000 0.000 0.000 0.000 0.250 0.000 0.985 0.993 0.998 
+ 993 0.246 0.000 0.000 0.000 0.000 0.243 0.000 0.985 0.993 0.997 
+ 994 0.241 0.000 0.000 0.000 0.000 0.238 0.000 0.985 0.993 0.999 
+ 995 0.235 0.000 0.000 0.000 0.000 0.232 0.000 0.985 0.993 0.999 
+ 996 0.229 0.000 0.000 0.000 0.000 0.227 0.000 0.985 0.993 0.999 
+ 997 0.224 0.000 0.000 0.000 0.000 0.221 0.000 0.985 0.993 0.999 
+ 998 0.218 0.000 0.000 0.000 0.000 0.216 0.000 0.985 0.993 0.999 
+ 999 0.213 0.000 0.000 0.000 0.000 0.211 0.000 0.985 0.993 0.999 
+1000 0.208 0.000 0.000 0.000 0.000 0.205 0.000 0.985 0.993 0.999 
+1001 0.203 0.000 0.000 0.000 0.000 0.200 0.000 0.985 0.993 0.999 
+1002 0.197 0.000 0.000 0.000 0.000 0.195 0.000 0.985 0.993 0.997 
+1003 0.192 0.000 0.000 0.000 0.000 0.189 0.000 0.985 0.993 0.999 
+1004 0.186 0.000 0.000 0.000 0.000 0.183 0.000 0.985 0.993 0.999 
+1005 0.181 0.000 0.000 0.000 0.000 0.178 0.000 0.985 0.993 1.000 
+1006 0.176 0.000 0.000 0.000 0.000 0.173 0.000 0.986 0.993 0.999 
+1007 0.171 0.000 0.000 0.000 0.000 0.168 0.000 0.986 0.993 0.999 
+1008 0.165 0.000 0.000 0.000 0.000 0.162 0.000 0.986 0.993 0.999 
+1009 0.160 0.000 0.000 0.000 0.000 0.157 0.000 0.986 0.993 0.998 
+1010 0.155 0.000 0.000 0.000 0.000 0.152 0.000 0.986 0.993 0.998 
+1011 0.149 0.000 0.000 0.000 0.000 0.147 0.000 0.986 0.993 0.999 
+1012 0.143 0.000 0.000 0.000 0.000 0.141 0.000 0.986 0.993 0.999 
+1013 0.138 0.000 0.000 0.000 0.000 0.136 0.000 0.986 0.993 1.000 
+1014 0.133 0.000 0.000 0.000 0.000 0.131 0.000 0.986 0.993 1.000 
+1015 0.129 0.000 0.000 0.000 0.000 0.127 0.000 0.986 0.993 0.999 
+1016 0.126 0.000 0.000 0.000 0.000 0.124 0.000 0.986 0.994 0.999 
+1017 0.122 0.000 0.000 0.000 0.000 0.120 0.000 0.986 0.993 0.999 
+1018 0.118 0.000 0.000 0.000 0.000 0.116 0.000 0.986 0.994 0.999 
+1019 0.113 0.000 0.000 0.000 0.000 0.111 0.000 0.986 0.994 0.999 
+1020 0.108 0.000 0.000 0.000 0.000 0.106 0.000 0.986 0.994 1.000 
+1021 0.103 0.000 0.000 0.000 0.000 0.102 0.000 0.986 0.994 1.000 
+1022 0.098 0.000 0.000 0.000 0.000 0.097 0.000 0.986 0.994 0.999 
+1023 0.095 0.000 0.000 0.000 0.000 0.094 0.000 0.986 0.994 0.999 
+1024 0.092 0.000 0.000 0.000 0.000 0.091 0.000 0.986 0.994 0.998 
+1025 0.089 0.000 0.000 0.000 0.000 0.088 0.000 0.986 0.994 1.000 
+1026 0.085 0.000 0.000 0.000 0.000 0.084 0.000 0.986 0.994 0.999 
+1027 0.082 0.000 0.000 0.000 0.000 0.081 0.000 0.986 0.994 0.999 
+1028 0.079 0.000 0.000 0.000 0.000 0.078 0.000 0.986 0.994 0.999 
+1029 0.076 0.000 0.000 0.000 0.000 0.075 0.000 0.986 0.994 0.999 
+1030 0.072 0.000 0.000 0.000 0.000 0.071 0.000 0.986 0.994 1.000 
+1031 0.068 0.000 0.000 0.000 0.000 0.067 0.000 0.986 0.994 0.999 
+1032 0.065 0.000 0.000 0.000 0.000 0.064 0.000 0.986 0.994 1.000 
+1033 0.061 0.000 0.000 0.000 0.000 0.060 0.000 0.986 0.994 1.000 
+1034 0.058 0.000 0.000 0.000 0.000 0.057 0.000 0.986 0.994 1.000 
+1035 0.056 0.000 0.000 0.000 0.000 0.055 0.000 0.986 0.994 1.000 
+1036 0.053 0.000 0.000 0.000 0.000 0.053 0.000 0.986 0.994 0.999 
+1037 0.051 0.000 0.000 0.000 0.000 0.050 0.000 0.986 0.994 0.999 
+1038 0.049 0.000 0.000 0.000 0.000 0.048 0.000 0.986 0.994 0.999 
+1039 0.046 0.000 0.000 0.000 0.000 0.045 0.000 0.986 0.994 0.999 
+1040 0.044 0.000 0.000 0.000 0.000 0.043 0.000 0.986 0.994 0.999 
+1041 0.042 0.000 0.000 0.000 0.000 0.041 0.000 0.986 0.994 0.999 
+1042 0.040 0.000 0.000 0.000 0.000 0.039 0.000 0.986 0.994 0.999 
+1043 0.038 0.000 0.000 0.000 0.000 0.037 0.000 0.986 0.994 0.999 
+1044 0.037 0.000 0.000 0.000 0.000 0.036 0.000 0.986 0.994 0.999 
+1045 0.036 0.000 0.000 0.000 0.000 0.035 0.000 0.986 0.994 0.999 
+1046 0.035 0.000 0.000 0.000 0.000 0.034 0.000 0.986 0.994 0.999 
+1047 0.034 0.000 0.000 0.000 0.000 0.033 0.000 0.986 0.994 0.999 
+1048 0.032 0.000 0.000 0.000 0.000 0.032 0.000 0.987 0.994 0.998 
+1049 0.031 0.000 0.000 0.000 0.000 0.030 0.000 0.987 0.994 0.998 
+1050 0.029 0.000 0.000 0.000 0.000 0.029 0.000 0.987 0.994 0.998 
+1051 0.028 0.000 0.000 0.000 0.000 0.028 0.000 0.987 0.994 0.998 
+1052 0.027 0.000 0.000 0.000 0.000 0.027 0.000 0.987 0.994 0.997 
+1053 0.026 0.000 0.000 0.000 0.000 0.026 0.000 0.987 0.994 0.997 
+1054 0.025 0.000 0.000 0.000 0.000 0.025 0.000 0.987 0.994 0.996 
+1055 0.024 0.000 0.000 0.000 0.000 0.024 0.000 0.987 0.994 0.996 
+1056 0.023 0.000 0.000 0.000 0.000 0.023 0.000 0.987 0.994 0.995 
+1057 0.022 0.000 0.000 0.000 0.000 0.022 0.000 0.987 0.994 0.994 
+1058 0.022 0.000 0.000 0.000 0.000 0.021 0.000 0.987 0.994 0.994 
+1059 0.020 0.000 0.000 0.000 0.000 0.020 0.000 0.987 0.994 0.993 
+1060 0.019 0.000 0.000 0.000 0.000 0.019 0.000 0.987 0.995 0.992 
+1061 0.018 0.000 0.000 0.000 0.000 0.018 0.000 0.987 0.995 0.992 
+1062 0.017 0.000 0.000 0.000 0.000 0.017 0.000 0.987 0.995 0.991 
+1063 0.017 0.000 0.000 0.000 0.000 0.016 0.000 0.987 0.995 0.991 
+1064 0.016 0.000 0.000 0.000 0.000 0.015 0.000 0.987 0.995 0.990 
+1065 0.015 0.000 0.000 0.000 0.000 0.015 0.000 0.987 0.995 0.989 
+1066 0.015 0.000 0.000 0.000 0.000 0.014 0.000 0.987 0.995 0.989 
+1067 0.014 0.000 0.000 0.000 0.000 0.014 0.000 0.987 0.995 0.990 
+1068 0.014 0.000 0.000 0.000 0.000 0.013 0.000 0.987 0.995 0.989 
+1069 0.013 0.000 0.000 0.000 0.000 0.012 0.000 0.987 0.995 0.991 
+1070 0.012 0.000 0.000 0.000 0.000 0.012 0.000 0.987 0.995 0.992 
+1071 0.012 0.000 0.000 0.000 0.000 0.011 0.000 0.987 0.995 0.994 
+1072 0.011 0.000 0.000 0.000 0.000 0.011 0.000 0.987 0.995 0.994 
+1073 0.011 0.000 0.000 0.000 0.000 0.011 0.000 0.987 0.995 0.995 
+1074 0.011 0.000 0.000 0.000 0.000 0.010 0.000 0.987 0.995 0.997 
+1075 0.010 0.000 0.000 0.000 0.000 0.010 0.000 0.987 0.995 0.994 
+1076 0.009 0.000 0.000 0.000 0.000 0.009 0.000 0.987 0.995 0.997 
+1077 0.009 0.000 0.000 0.000 0.000 0.009 0.000 0.987 0.995 0.995 
+1078 0.008 0.000 0.000 0.000 0.000 0.008 0.000 0.987 0.995 0.996 
+1079 0.008 0.000 0.000 0.000 0.000 0.008 0.000 0.987 0.995 0.998 
+1080 0.008 0.000 0.000 0.000 0.000 0.008 0.000 0.987 0.995 0.994 
+1081 0.007 0.000 0.000 0.000 0.000 0.007 0.000 0.987 0.995 0.994 
+1082 0.007 0.000 0.000 0.000 0.000 0.007 0.000 0.987 0.995 0.998 
+1083 0.007 0.000 0.000 0.000 0.000 0.007 0.000 0.987 0.995 0.999 
+1084 0.006 0.000 0.000 0.000 0.000 0.006 0.000 0.987 0.995 0.991 
+1085 0.006 0.000 0.000 0.000 0.000 0.006 0.000 0.987 0.995 0.996 
+1086 0.006 0.000 0.000 0.000 0.000 0.006 0.000 0.987 0.995 0.985 
+1087 0.006 0.000 0.000 0.000 0.000 0.006 0.000 0.987 0.995 0.995 
+1088 0.006 0.000 0.000 0.000 0.000 0.005 0.000 0.987 0.995 0.997 
+1089 0.005 0.000 0.000 0.000 0.000 0.005 0.000 0.988 0.995 0.995 
+1090 0.005 0.000 0.000 0.000 0.000 0.005 0.000 0.988 0.995 0.987 
+1091 0.005 0.000 0.000 0.000 0.000 0.005 0.000 0.988 0.995 0.996 
+1092 0.004 0.000 0.000 0.000 0.000 0.004 0.000 0.988 0.995 0.998 
+1093 0.004 0.000 0.000 0.000 0.000 0.004 0.000 0.988 0.995 0.978 
+1094 0.004 0.000 0.000 0.000 0.000 0.004 0.000 0.988 0.995 0.995 
+1095 0.004 0.000 0.000 0.000 0.000 0.004 0.000 0.988 0.995 0.985 
+1096 0.003 0.000 0.000 0.000 0.000 0.003 0.000 0.988 0.995 0.981 
+1097 0.003 0.000 0.000 0.000 0.000 0.003 0.000 0.988 0.995 0.998 
+1098 0.003 0.000 0.000 0.000 0.000 0.003 0.000 0.988 0.995 0.981 
+1099 0.003 0.000 0.000 0.000 0.000 0.003 0.000 0.988 0.995 0.983 
+1100 0.003 0.000 0.000 0.000 0.000 0.002 0.000 0.988 0.995 0.972 
Index: /branches/eam_branches/ipp-20130904/dvodist/ippdata/ps1.filters/index.mkd
===================================================================
--- /branches/eam_branches/ipp-20130904/dvodist/ippdata/ps1.filters/index.mkd	(revision 36192)
+++ /branches/eam_branches/ipp-20130904/dvodist/ippdata/ps1.filters/index.mkd	(revision 36192)
@@ -0,0 +1,8 @@
+<?php include "@HTDOCS@/www-util/ippdata.page.php"; ?>
+
+# PS1 Filter Bandpasses
+
+(up to [PS1 Data Release](@WWWHOST@/index.php))
+
+@ Data Product                : none                       : plain : title : Comment
+@ PS1 Filter Table            : apj425122t3_mrt.txt        : file  : dir1  : Filter Bandpass table (txt)
Index: /branches/eam_branches/ipp-20130904/ippScripts/scripts/receive_file.pl
===================================================================
--- /branches/eam_branches/ipp-20130904/ippScripts/scripts/receive_file.pl	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippScripts/scripts/receive_file.pl	(revision 36192)
@@ -239,9 +239,10 @@
     }
 
-    if ($stage eq 'sky' or $stage = 'skycal') {
+    if ($stage eq 'sky' or $stage eq 'skycal') {
         # the dbinfo file for staticskyRun and skycalRun only have one component and they don't contain
         # skycell_id which is the way components are listed in the dirinfo file.
         my @ids = keys %$components;
-        &my_die( "unexpected number of components scalar @ids found in staticsky dirinfo file\n", $file_id, $PS_EXIT_UNKNOWN_ERROR) if scalar @ids != 1;
+        my $nComponents = scalar @ids;
+        &my_die( "unexpected number of components $nComponents found in $stage dirinfo file\n", $file_id, $PS_EXIT_UNKNOWN_ERROR) if $nComponents  != 1;
         $current_component = $ids[0];
     }
Index: /branches/eam_branches/ipp-20130904/ippScripts/scripts/warp_skycell.pl
===================================================================
--- /branches/eam_branches/ipp-20130904/ippScripts/scripts/warp_skycell.pl	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippScripts/scripts/warp_skycell.pl	(revision 36192)
@@ -388,12 +388,12 @@
 	    $quality = 8006; # bad data.
 	}
-#         if (!$quality) {
-#             check_output($outputImage, 0);
-#             check_output($outputMask, 0);
-#             check_output($outputWeight, 0);
-#             check_output($outputSources, 1);
-#             check_output($outputPSF, 1) if metadataLookupBool($recipe, 'PSF')  ;
-#         }
 	print "Quality: $quality\n";
+        if (!$quality) {
+            check_output($outputImage, 0);
+            check_output($outputMask, 0);
+            check_output($outputWeight, 0);
+            check_output($outputSources, 0);
+            check_output($outputPSF, 0) if metadataLookupBool($recipe, 'PSF')  ;
+        }
 
         # $run_state eq 'update'
Index: /branches/eam_branches/ipp-20130904/ippToPsps/jython/dxlayer.py
===================================================================
--- /branches/eam_branches/ipp-20130904/ippToPsps/jython/dxlayer.py	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippToPsps/jython/dxlayer.py	(revision 36192)
@@ -25,4 +25,5 @@
     '''
     def deleteBatch(self, batchID):
+        #HAF This is really lazy to do this way, but for the time, will check both dx layers and try the first, if no go try the second.
 
         batch = Batch.getNameFromID(batchID)
@@ -46,8 +47,36 @@
         p.stdout.close()
 
-        if ret: self.logger.infoPair("Deleted batch from DXLayer", batch) 
-        else: self.logger.errorPair("Unable to delete batch from DXLayer", batch)
+        if ret: self.logger.infoPair("Deleted batch from DXLayer 1", batch) 
+        else: self.logger.errorPair("Unable to delete batch from DXLayer 1" , batch)
+
+
+       
+
+        tempFile = tempfile.NamedTemporaryFile(mode='w+b')
+
+        p = Popen("deleteFromDXLayer2.pl -b " + batch + " -f " + tempFile.name, 
+                shell=True, 
+                stdout=PIPE)
+        p.wait()
+       
+        if p.returncode != 0:
+           self.logger.debugPair("DXLayer webservice", "failed")
+           return 0
+        else:
+           self.logger.debugPair("DXLayer webservice", "successful")
+
+        ret = self.decodeDXLayerResponse(tempFile.name)
+
+        tempFile.close()
+        p.stdout.close()
+
+        if ret: self.logger.infoPair("Deleted batch from DXLayer 2", batch) 
+        else: self.logger.errorPair("Unable to delete batch from DXLayer 2" , batch)
+
+
+
 
         return ret
+
 
     '''
Index: /branches/eam_branches/ipp-20130904/ippToPsps/jython/ipptopspsdb.py
===================================================================
--- /branches/eam_branches/ipp-20130904/ippToPsps/jython/ipptopspsdb.py	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippToPsps/jython/ipptopspsdb.py	(revision 36192)
@@ -39,4 +39,6 @@
                AND batch_type = '" + batchType + "' \
                AND dvo_db = '" + self.skychunk.dvoLabel + "' \
+               AND comment = '" + self.skychunk.name + "' \
+               AND datastore_product = '" + self.skychunk.datastoreProduct + "' \
                AND merged = 1 \
                AND deleted_local = 0 \
@@ -65,4 +67,6 @@
                AND batch_type = '" + batchType + "' \
                AND dvo_db = '" + self.skychunk.dvoLabel + "' \
+               AND comment = '" + self.skychunk.name + "' \
+               AND datastore_product = '" + self.skychunk.datastoreProduct + "' \
                AND purged = 1 \
                AND deleted_local = 0 \
@@ -92,4 +96,6 @@
                AND batch_type = '" + batchType + "' \
                AND dvo_db = '" + self.skychunk.dvoLabel + "' \
+               AND comment = '" + self.skychunk.name + "' \
+               AND datastore_product = '" + self.skychunk.datastoreProduct + "' \
                AND purged = 1 \
                AND deleted_datastore = 0 \
@@ -119,5 +125,7 @@
                AND batch_type = '" + batchType + "' \
                AND dvo_db = '" + self.skychunk.dvoLabel + "' \
-               AND (loaded_to_ODM = -1 OR merge_worthy = 1) \
+               AND comment = '" + self.skychunk.name + "' \
+               AND datastore_product = '" + self.skychunk.datastoreProduct + "' \
+               AND (merge_worthy = 1) \
                AND deleted_datastore = 0 AND block_delete_datastore = 0"
 
@@ -144,5 +152,5 @@
                AND batch_type = '" + batchType + "' \
                AND dvo_db = '" + self.skychunk.dvoLabel + "' \
-               AND (loaded_to_ODM = -1 OR merge_worthy = 1) \
+               AND (merge_worthy = 1) \
                AND deleted_dxlayer = 0 and block_delete_dxlayer = 0"
 
Index: /branches/eam_branches/ipp-20130904/ippToPsps/jython/stackbatch.py
===================================================================
--- /branches/eam_branches/ipp-20130904/ippToPsps/jython/stackbatch.py	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippToPsps/jython/stackbatch.py	(revision 36192)
@@ -645,5 +645,5 @@
         ,petRadiusErr=b.PETRO_RADIUS_ERR \
         ,petFlux=POW(10.0, -0.4 * b.PETRO_MAG) /" + str(self.expTime) + " \
-        ,petFluxErr=ABS(b.PETRO_MAG_ERR) * POW(10.0, (-0.4*b.PETRO_MAG)) / " + str(self.expTime) + " / 1.085736  \
+        ,petFluxErr=-999  \
         ,petR50=b.PETRO_RADIUS_50 \
         ,petR50Err=b.PETRO_RADIUS_50_ERR \
@@ -653,4 +653,15 @@
         WHERE a.ippDetectID=b.IPP_IDET"
         self.scratchDb.execute(sql)
+
+        self.logger.infoPair("Adding", "petFluxErr for non nulls")
+        sql = "UPDATE StackApFlx as a, SkyChip_xsrc AS b SET \
+        petFluxErr=ABS(b.PETRO_MAG_ERR) * POW(10.0, (-0.4*b.PETRO_MAG)) / " + str(self.expTime) + " / 1.085736  \
+        WHERE a.ippDetectID=b.IPP_IDET \
+        AND (b.PETRO_MAG_ERR is not NULL AND b.PETRO_MAG is not NULL AND PETRO_MAG_ERR < 1000.0)"
+        # added this because when the petromagerr is crazy large (10^29 it out of ranges the flux err calc)
+        self.logger.infoPair("sql", sql)
+        self.scratchDb.execute(sql)
+
+
 
         self.logger.infoPair("adding"," PrimaryF to stackApFlx")
Index: /branches/eam_branches/ipp-20130904/ippconfig/gpc1/ppImage.config
===================================================================
--- /branches/eam_branches/ipp-20130904/ippconfig/gpc1/ppImage.config	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippconfig/gpc1/ppImage.config	(revision 36192)
@@ -34,5 +34,5 @@
 # aditional auxiliary mask applied to corners of all chips in video cells.
 # Is only applied if MASK.AUXMASK and USE.VIDEO.MASK are both true
-AUX.VIDEO.MASK  STR     neb://any/gpc1/auxmask/mpg.20130506/mask_video_cell_corners.fits
+AUX.VIDEO.MASK  STR     neb://any/gpc1/auxmask/mpg.20130930/mask_video_cell_corners.fits
 
 
@@ -189,4 +189,37 @@
 END
 
+CHIP_NOCOMPRESS METADATA
+  BASE.FITS          BOOL    FALSE           # Save base detrended image?
+  BASE.MASK.FITS     BOOL    FALSE           # Save base detrended image?
+  BASE.VARIANCE.FITS BOOL    FALSE           # Save base detrended image?
+  CHIP.FITS          BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.MASK.FITS     BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.VARIANCE.FITS BOOL    TRUE            # Save chip-mosaic-ed image? 
+  OVERSCAN           BOOL    TRUE            # Overscan subtraction
+  NONLIN             BOOL    TRUE            # apply non-linearity correction 
+  BIAS               BOOL    FALSE           # Bias subtraction
+  DARK               BOOL    TRUE            # Dark subtraction
+  NOISEMAP	     BOOL    TRUE	     
+  REMNANCE           BOOL    FALSE           # Remnance masking
+  SHUTTER            BOOL    FALSE           # Shutter correction
+  FLAT               BOOL    TRUE            # Flat-field normalisation
+  MASK               BOOL    TRUE            # Mask bad pixels
+  MASK.BUILD	     BOOL    TRUE	     # Build internal mask?
+  MASK.BURNTOOL      BOOL    TRUE            # Mask potential burntool trails
+  MASK.AUXMASK       BOOL    FALSE           # augment mask with more restrictive auxiliary mask
+  PATTERN.ROW        BOOL    TRUE            # Row pattern correction
+  PATTERN.CELL	     BOOL    FALSE	     # Cell pattern correction
+  PATTERN.CONTINUITY BOOL    TRUE            # Cell pattern correction using edge continuity
+  FRINGE             BOOL    TRUE            # Fringe subtraction
+  BIN1.FITS          BOOL    TRUE            # Save 1st binned chip image?
+  BIN2.FITS          BOOL    TRUE            # Save 2nd binned chip image?
+  PHOTOM             BOOL    TRUE            # Source identification and photometry
+  ASTROM.CHIP        BOOL    FALSE           # Astrometry per chip?
+  ASTROM.MOSAIC      BOOL    FALSE           # Astrometry for mosaic?
+  BACKGROUND         BOOL    TRUE            # Subtract background?
+  CROSSTALK.MEASURE  BOOL    FALSE           # Subtract model background?
+  NO.COMPRESS        BOOL    TRUE            # do not compress images
+END
+
 # Chip processing for testing pattern correction
 CHIP_PATTERNTEST METADATA
@@ -1259,4 +1292,96 @@
   CROSSTALK.MEASURE  BOOL    FALSE           # Subtract model background?
   NO.COMPRESS        BOOL    TRUE            # turn off image compression
+    DETREND.CONSTRAINTS  METADATA
+      BIAS METADATA
+      END
+      DARK METADATA
+        EXPTIME STR FPA.EXPOSURE
+      END
+      FLAT METADATA
+        FILTER  STR FPA.FILTERID
+      END
+      FLATCORR METADATA
+        FILTER   STR FPA.FILTERID
+      END
+      FRINGE METADATA
+        FILTER   STR FPA.FILTERID
+      END
+      SHUTTER METADATA
+      END
+      MASK METADATA
+      END	
+      AUXMASK METADATA
+        DETTYPE STR AUXMASK_STS
+      END
+      ASTROM METADATA
+      END	
+      NOISEMAP METADATA
+      END	
+      LINEARITY METADATA
+      END
+    END
+END
+
+# Standard chip processing + auxiliary mask with heavy masking
+CHIP_AUXMASK_HEAVY METADATA
+  BASE.FITS          BOOL    FALSE           # Save base detrended image?
+  BASE.MASK.FITS     BOOL    FALSE           # Save base detrended image?
+  BASE.VARIANCE.FITS BOOL    FALSE           # Save base detrended image?
+  CHIP.FITS          BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.MASK.FITS     BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.VARIANCE.FITS BOOL    TRUE            # Save chip-mosaic-ed image? 
+  OVERSCAN           BOOL    TRUE            # Overscan subtraction
+  NONLIN             BOOL    TRUE            # apply non-linearity correction 
+  BIAS               BOOL    FALSE           # Bias subtraction
+  DARK               BOOL    TRUE            # Dark subtraction
+  NOISEMAP	     BOOL    TRUE	     
+  REMNANCE           BOOL    FALSE           # Remnance masking
+  SHUTTER            BOOL    FALSE           # Shutter correction
+  FLAT               BOOL    TRUE            # Flat-field normalisation
+  MASK               BOOL    TRUE            # Mask bad pixels
+  MASK.BUILD	     BOOL    TRUE	     # Build internal mask?
+  MASK.BURNTOOL      BOOL    TRUE            # Mask potential burntool trails
+  MASK.AUXMASK       BOOL    TRUE            # augment mask with more restrictive auxiliary mask
+  PATTERN.ROW        BOOL    TRUE            # Row pattern correction
+  PATTERN.CELL	     BOOL    FALSE	     # Cell pattern correction
+  PATTERN.CONTINUITY BOOL    TRUE            # Cell pattern correction using edge continuity
+  FRINGE             BOOL    TRUE            # Fringe subtraction
+  BIN1.FITS          BOOL    TRUE            # Save 1st binned chip image?
+  BIN2.FITS          BOOL    TRUE            # Save 2nd binned chip image?
+  PHOTOM             BOOL    TRUE            # Source identification and photometry
+  ASTROM.CHIP        BOOL    FALSE           # Astrometry per chip?
+  ASTROM.MOSAIC      BOOL    FALSE           # Astrometry for mosaic?
+  BACKGROUND         BOOL    TRUE            # Subtract background?
+  CROSSTALK.MEASURE  BOOL    FALSE           # Subtract model background?
+  NO.COMPRESS        BOOL    TRUE            # turn off image compression
+    DETREND.CONSTRAINTS  METADATA
+      BIAS METADATA
+      END
+      DARK METADATA
+        EXPTIME STR FPA.EXPOSURE
+      END
+      FLAT METADATA
+        FILTER  STR FPA.FILTERID
+      END
+      FLATCORR METADATA
+        FILTER   STR FPA.FILTERID
+      END
+      FRINGE METADATA
+        FILTER   STR FPA.FILTERID
+      END
+      SHUTTER METADATA
+      END
+      MASK METADATA
+      END	
+      AUXMASK METADATA
+        DETTYPE STR AUXMASK_HEAVY
+      END
+      ASTROM METADATA
+      END	
+      NOISEMAP METADATA
+      END	
+      LINEARITY METADATA
+      END
+    END
 END
 
@@ -1359,4 +1484,33 @@
   CROSSTALK.MEASURE  BOOL    FALSE           # Subtract model background?
   NO.COMPRESS        BOOL    TRUE            # turn off image compression
+    DETREND.CONSTRAINTS  METADATA
+      BIAS METADATA
+      END
+      DARK METADATA
+        EXPTIME STR FPA.EXPOSURE
+      END
+      FLAT METADATA
+        FILTER  STR FPA.FILTERID
+      END
+      FLATCORR METADATA
+        FILTER   STR FPA.FILTERID
+      END
+      FRINGE METADATA
+        FILTER   STR FPA.FILTERID
+      END
+      SHUTTER METADATA
+      END
+      MASK METADATA
+      END	
+      AUXMASK METADATA
+        DETTYPE STR AUXMASK_HEAVY
+      END
+      ASTROM METADATA
+      END	
+      NOISEMAP METADATA
+      END	
+      LINEARITY METADATA
+      END
+    END
 END
 
Index: /branches/eam_branches/ipp-20130904/ippconfig/gpc1/ppStack.config
===================================================================
--- /branches/eam_branches/ipp-20130904/ippconfig/gpc1/ppStack.config	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippconfig/gpc1/ppStack.config	(revision 36192)
@@ -125,9 +125,14 @@
 END
 
-STACK_NIGHTLY_1DG  METADATA                 # Typically MD 8 input nightly stacks and using 1DG convolution
-    OUTPUT.NOCOMP      BOOL  FALSE
-    OUTPUT.LOGFLUX     BOOL  FALSE
-    PSF.TARGET.AS.MAX  BOOL  TRUE
-    PSF.TARGET.AS.MAX.EPSILON F32 0.1
+STACK_NIGHTLY_1DG  METADATA                 # Revised MD 8 input nightly stacks and using 1DG convolution
+    OUTPUT.NOCOMP             BOOL  FALSE
+    OUTPUT.LOGFLUX            BOOL  FALSE
+    PSF.INPUT.CLIP.SIMPLE     BOOL  True
+    PSF.INPUT.MAX             F32   12.0    # what FWHM does diffim become mostly useless, if any?
+    PSF.INPUT.CLIP.NSIGMA     F32   1000.0  # want to use up to MAX, but sig could possibly be small?
+    MATCH.REJ                 F32   4.0     # need to tune?
+    SAFE                      BOOL  FALSE
+    PSF.TARGET.AS.MAX         BOOL  TRUE
+    PSF.TARGET.AS.MAX.EPSILON F32   0.1
 END
 
@@ -138,9 +143,9 @@
     STACK.TYPE              STR   DEEP_STACK  ## needed?
     PSF.INPUT.CLIP.SIMPLE   BOOL  True
-    PSF.INPUT.MAX           F32   6.0   # never really want >6 pixels in refstack
+    PSF.INPUT.MAX           F32   6.0   # never really want >6 pixels in refstack, even on edges 
     PSF.INPUT.CLIP.NSIGMA   F32   1.0   # sample typically on rising side of distribution (set even smaller?)
     PSF.INPUT.THRESH        F32   NAN
     PSF.INPUT.ASYMMETRY     F32   NAN
-    MATCH.REJ               F32   4.0 # need ot tune?
+    MATCH.REJ               F32   4.0   # need ot tune?
     SAFE                    BOOL  FALSE
     PSF.TARGET.AS.MAX       BOOL  TRUE      # Set the target PSF FWHM as the maximum of accepted input FWHM values.
@@ -154,9 +159,9 @@
     STACK.TYPE              STR   DEEP_STACK
     PSF.INPUT.CLIP.SIMPLE   BOOL  True
-    PSF.INPUT.MAX           F32   10.0
+    PSF.INPUT.MAX           F32   10.0    #  
     PSF.INPUT.CLIP.NSIGMA   F32   100.0
     PSF.INPUT.THRESH        F32   NAN
     PSF.INPUT.ASYMMETRY     F32   NAN
-    MATCH.REJ               F32   4.0 # need ot tune?
+    MATCH.REJ               F32   4.0     # need ot tune?
     SAFE                    BOOL  FALSE
     PSF.TARGET.AS.MAX  BOOL  TRUE
@@ -164,5 +169,5 @@
 END
 
-STACK_ALLDEEP_1DG      METADATA     # no cuts, everything in changes after ppStack mods 5/03/13
+STACK_ALLDEEP_1DG      METADATA     # no real cuts, for changes after ppStack mods 5/03/13
     OUTPUT.NOCOMP           BOOL  TRUE
     OUTPUT.LOGFLUX          BOOL  FALSE
@@ -170,9 +175,9 @@
     STACK.TYPE              STR   DEEP_STACK
     PSF.INPUT.CLIP.SIMPLE   BOOL  True
-    PSF.INPUT.MAX           F32   100.0
+    PSF.INPUT.MAX           F32   14.0    # greater than 14 is more often junk
     PSF.INPUT.CLIP.NSIGMA   F32   100.0
     PSF.INPUT.THRESH        F32   NAN
     PSF.INPUT.ASYMMETRY     F32   NAN
-    MATCH.REJ               F32   4.0 # need ot tune?
+    MATCH.REJ               F32   4.0     # need ot tune?
     SAFE                    BOOL  FALSE
     PSF.TARGET.AS.MAX  BOOL  TRUE
Index: /branches/eam_branches/ipp-20130904/ippconfig/recipes/filerules-split.mdc
===================================================================
--- /branches/eam_branches/ipp-20130904/ippconfig/recipes/filerules-split.mdc	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippconfig/recipes/filerules-split.mdc	(revision 36192)
@@ -38,4 +38,5 @@
 PPIMAGE.INPUT.MASK        INPUT    @FILES        CHIP       MASK
 PPIMAGE.VIDEOMASK         INPUT    @DETDB        CHIP       MASK
+PPIMAGE.AUXMASK           INPUT    @DETDB        CHIP       MASK
 PPIMAGE.INPUT.VARIANCE    INPUT    @FILES        CHIP       VARIANCE
 PPIMAGE.INPUT.PSF         INPUT    @FILES        CHIP       PSF
Index: /branches/eam_branches/ipp-20130904/ippconfig/recipes/ppImage.config
===================================================================
--- /branches/eam_branches/ipp-20130904/ippconfig/recipes/ppImage.config	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippconfig/recipes/ppImage.config	(revision 36192)
@@ -194,7 +194,57 @@
   MASK.STATS         BOOL    TRUE            # Calculate Mask statistics.
 END
-
 # Standard chip processing
+CHIP_NOCOMPRESS	METADATA
+  BASE.FITS          BOOL    FALSE           # Save base detrended image?
+  BASE.MASK.FITS     BOOL    FALSE           # Save base detrended image?
+  BASE.VARIANCE.FITS BOOL    FALSE           # Save base detrended image?
+  CHIP.FITS          BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.MASK.FITS     BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.VARIANCE.FITS BOOL    TRUE            # Save chip-mosaic-ed image? 
+  OVERSCAN           BOOL    TRUE            # Overscan subtraction
+  NONLIN             BOOL    FALSE           # Non-linearity correction; not implemented
+  BIAS               BOOL    TRUE            # Bias subtraction
+  DARK               BOOL    TRUE            # Dark subtraction
+  SHUTTER            BOOL    FALSE           # Shutter correction
+  FLAT               BOOL    TRUE            # Flat-field normalisation
+  MASK               BOOL    TRUE            # Mask bad pixels
+  FRINGE             BOOL    TRUE            # Fringe subtraction
+  BIN1.FITS          BOOL    TRUE            # Save 1st binned chip image?
+  BIN2.FITS          BOOL    TRUE            # Save 2nd binned chip image?
+  PHOTOM             BOOL    TRUE            # Source identification and photometry
+  ASTROM.CHIP        BOOL    FALSE           # Astrometry per chip?
+  ASTROM.MOSAIC      BOOL    FALSE           # Astrometry for mosaic?
+  BACKGROUND         BOOL    TRUE            # Subtract background?
+  MASK.STATS         BOOL    TRUE            # Calculate Mask statistics.
+  NO.COMPRESS        BOOL    TRUE
+END
+
+# Standard chip processing with auxillary masking
 CHIP_AUXMASK	METADATA
+  BASE.FITS          BOOL    FALSE           # Save base detrended image?
+  BASE.MASK.FITS     BOOL    FALSE           # Save base detrended image?
+  BASE.VARIANCE.FITS BOOL    FALSE           # Save base detrended image?
+  CHIP.FITS          BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.MASK.FITS     BOOL    TRUE            # Save chip-mosaic-ed image? 
+  CHIP.VARIANCE.FITS BOOL    TRUE            # Save chip-mosaic-ed image? 
+  OVERSCAN           BOOL    TRUE            # Overscan subtraction
+  NONLIN             BOOL    FALSE           # Non-linearity correction; not implemented
+  BIAS               BOOL    TRUE            # Bias subtraction
+  DARK               BOOL    TRUE            # Dark subtraction
+  SHUTTER            BOOL    FALSE           # Shutter correction
+  FLAT               BOOL    TRUE            # Flat-field normalisation
+  MASK               BOOL    TRUE            # Mask bad pixels
+  FRINGE             BOOL    TRUE            # Fringe subtraction
+  BIN1.FITS          BOOL    TRUE            # Save 1st binned chip image?
+  BIN2.FITS          BOOL    TRUE            # Save 2nd binned chip image?
+  PHOTOM             BOOL    TRUE            # Source identification and photometry
+  ASTROM.CHIP        BOOL    FALSE           # Astrometry per chip?
+  ASTROM.MOSAIC      BOOL    FALSE           # Astrometry for mosaic?
+  BACKGROUND         BOOL    TRUE            # Subtract background?
+  MASK.STATS         BOOL    TRUE            # Calculate Mask statistics.
+END
+
+# Standard chip processing with heavy auxillary masking (same as CHIP_AUXMASK here, but different in gpc1)
+CHIP_AUXMASK_HEAVY	METADATA
   BASE.FITS          BOOL    FALSE           # Save base detrended image?
   BASE.MASK.FITS     BOOL    FALSE           # Save base detrended image?
Index: /branches/eam_branches/ipp-20130904/ippconfig/recipes/reductionClasses.mdc
===================================================================
--- /branches/eam_branches/ipp-20130904/ippconfig/recipes/reductionClasses.mdc	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/ippconfig/recipes/reductionClasses.mdc	(revision 36192)
@@ -1129,4 +1129,21 @@
    CHIP_PSPHOT STR CHIP
    WARP_PSWARP STR WARP
+   STACK_PPSTACK STR STACK
+   STACK_PPSUB STR STACK
+   STACK_PSPHOT STR STACK
+   DIFF_PPSUB  STR DIFF
+   DIFF_PSPHOT STR DIFF
+   JPEG_BIN1   STR PPIMAGE_J1
+   JPEG_BIN2   STR PPIMAGE_J2
+   FAKEPHOT    STR FAKEPHOT
+   ADDSTAR     STR ADDSTAR
+   PSASTRO     STR STS_DATASET
+   STACKPHOT   STR STACKPHOT
+END
+
+STS_DATASET_NOCOMPRESS METADATA
+   CHIP_PPIMAGE STR CHIP_NOCOMPRESS
+   CHIP_PSPHOT STR CHIP
+   WARP_PSWARP STR WARP_NOCOMPRESS
    STACK_PPSTACK   STR STACK
    STACK_PPSUB STR STACK
Index: /branches/eam_branches/ipp-20130904/pstamp/scripts/psmkreq
===================================================================
--- /branches/eam_branches/ipp-20130904/pstamp/scripts/psmkreq	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/pstamp/scripts/psmkreq	(revision 36192)
@@ -177,5 +177,6 @@
 $id = 0 if !$id;
 
-unless ($stage eq 'raw' or $stage eq 'chip' or $stage eq 'warp' or $stage eq 'diff' or $stage eq 'stack') {
+unless ($stage eq 'raw' or $stage eq 'chip' or $stage eq 'warp' or $stage eq 'diff' or $stage eq 'stack'
+    or $stage eq 'stack_summary') {
     die "$stage is not a valid value for stage\n";
 }
@@ -208,4 +209,5 @@
         $option_mask |= $PSTAMP_SELECT_PSF      if $psf;
         $option_mask |= $PSTAMP_SELECT_BACKMDL  if $backmdl;
+        $option_mask |= $PSTAMP_SELECT_UNCOMPRESSED   if $uncompressed;
         $option_mask |= $PSTAMP_SELECT_UNCONV   if $unconvolved;
         $option_mask |= $PSTAMP_USE_IMFILE_ID   if $use_imfile_id;
Index: /branches/eam_branches/ipp-20130904/pstamp/scripts/pstamp_checkdependent.pl
===================================================================
--- /branches/eam_branches/ipp-20130904/pstamp/scripts/pstamp_checkdependent.pl	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/pstamp/scripts/pstamp_checkdependent.pl	(revision 36192)
@@ -304,4 +304,20 @@
             }
             $queued_update = 1;
+        } elsif ($chip->{state} eq 'cleaned' and $chip->{data_state} eq 'update') {
+            # we've had a number of runs in this limbo state
+
+            my $command = "$chiptool -updaterun -set_state update -chip_id $chip_id";
+            $command .= " -set_label $rlabel" if $rlabel;
+
+            if (!$no_update) {
+                my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
+                            run(command => $command, verbose => $verbose);
+                unless ($success) {
+                    my_die("failed to change ${stage}Run $stage_id $component from goto_cleaned to update", $PS_EXIT_UNKNOWN_ERROR);
+                }
+            } else {
+                print "skipping $command\n";
+            }
+            $queued_update = 1;
         } elsif ($chip->{fault}) {
             $fault_count++;
@@ -460,4 +476,18 @@
             print "skipping $command\n";
         }
+    } elsif ($chips_ready and $skycell->{data_state} eq 'update' and $skycell->{state} ne 'update') {
+        my $command = "$warptool -updaterun -warp_id $warp_id -set_state update";
+        $command .= " -set_label $rlabel" if $rlabel;
+
+        if (!$no_update) {
+            my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
+                        run(command => $command, verbose => $verbose);
+            unless ($success) {
+                my_die("failed to change state of ${stage}Run $stage_id to update", $PS_EXIT_UNKNOWN_ERROR);
+            }
+        } else {
+            print "skipping $command\n";
+        }
+
     } elsif (scalar @chipsToUpdate > 0) {
         my $fault = check_states_chip($chip_id, \@chipsToUpdate, $rlabel, $need_magic);
Index: /branches/eam_branches/ipp-20130904/pstamp/scripts/pstamp_job_run.pl
===================================================================
--- /branches/eam_branches/ipp-20130904/pstamp/scripts/pstamp_job_run.pl	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/pstamp/scripts/pstamp_job_run.pl	(revision 36192)
@@ -236,8 +236,13 @@
                            $PSTAMP_SELECT_JPEG     => 'jpg',
                            $PSTAMP_SELECT_EXP      => 'exp.fits',
-                           $PSTAMP_SELECT_NUM      => 'num.fits');
+                           $PSTAMP_SELECT_NUM      => 'num.fits',
+                           $PSTAMP_SELECT_EXPJPEG  => 'exp.jpg',
+                           $PSTAMP_SELECT_NUMJPEG  => 'num.jpg');
 
         my $output_mask = $options & ($PSTAMP_SELECT_IMAGE | $PSTAMP_SELECT_MASK | $PSTAMP_SELECT_VARIANCE 
-            | $PSTAMP_SELECT_JPEG | $PSTAMP_SELECT_SOURCES | $PSTAMP_SELECT_EXP | $PSTAMP_SELECT_NUM);
+            | $PSTAMP_SELECT_JPEG | $PSTAMP_SELECT_SOURCES
+            | $PSTAMP_SELECT_EXP | $PSTAMP_SELECT_NUM 
+            | $PSTAMP_SELECT_EXPJPEG | $PSTAMP_SELECT_NUMJPEG);
+
 
         foreach my $key (keys (%extensions)) {
@@ -261,6 +266,6 @@
         close $F;
         $jobStatus = $PS_EXIT_SUCCESS;
-    } elsif ($exitStatus == $PSTAMP_NO_OVERLAP) {
-        $jobStatus = $PSTAMP_NO_OVERLAP;
+    } elsif ($exitStatus == $PSTAMP_NO_OVERLAP || $exitStatus == $PSTAMP_NO_VALID_PIXELS) {
+        $jobStatus = $exitStatus;
     } else {
         my_die( "ppstamp failed with error code: $exitStatus", $job_id, $exitStatus);
@@ -382,4 +387,7 @@
         my $backmdl_file = $params->{backmdl} if ($options & $PSTAMP_SELECT_BACKMDL);
         my $pattern_file = $params->{pattern} if ($options & $PSTAMP_SELECT_BACKMDL);
+        my $filter = $params->{filter};
+        $filter = ' ' if !$filter;
+	$filter = substr $filter, 0, 1;
         my $cmf_file;
 #        if ($stage ne 'chip') {
@@ -394,5 +402,8 @@
             if (!$therest or !$rownum or !$jobnum);
 
-        my $prefix = "${rownum}_${jobnum}_";
+        # XXX: Here we are assuming the form of the output file names
+	# if we change this in pstampparse we'll need to remember ....
+	# (the last time I forgot)
+        my $prefix = "${rownum}_${jobnum}_${filter}_";
 
         if ($cmf_file) {
@@ -573,4 +584,6 @@
     $params->{exp}    = $path_base . ".exp.b1.fits";
     $params->{num}    = $path_base . ".num.b1.fits";
+    $params->{expjpeg} = $path_base . ".exp.0.b1.jpeg";
+    $params->{numjpeg} = $path_base . ".num.0.b1.jpeg";
 }
 
@@ -632,4 +645,14 @@
         if (!myCopy("$outputBase.num.fits", $params->{num}, 'num', 0)) {
             $options &= ~$PSTAMP_SELECT_NUM;
+        }
+    }
+    if ($options & $PSTAMP_SELECT_EXPJPEG) {
+        if (!myCopy("$outputBase.exp.jpg", $params->{expjpeg}, 'exp', 0)) {
+            $options &= ~$PSTAMP_SELECT_EXPJPEG;
+        }
+    }
+    if ($options & $PSTAMP_SELECT_NUMJPEG) {
+        if (!myCopy("$outputBase.num.jpg", $params->{numjpeg}, 'num', 0)) {
+            $options &= ~$PSTAMP_SELECT_NUMJPEG;
         }
     }
Index: /branches/eam_branches/ipp-20130904/pstamp/scripts/pstampparse.pl
===================================================================
--- /branches/eam_branches/ipp-20130904/pstamp/scripts/pstampparse.pl	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/pstamp/scripts/pstampparse.pl	(revision 36192)
@@ -31,4 +31,5 @@
 my $no_update;
 my $dest_requires_magic;
+my $dump_params = 0;
 
 # set this to true to disable update processing
@@ -48,4 +49,5 @@
     'save-temps'=>  \$save_temps,
     'no-update' =>  \$no_update,
+    'dump-params' => \$dump_params,
 );
 
@@ -238,30 +240,17 @@
 
 
+# if label is for one of the high priority channels, watch for big requests
+my $watch_for_big_requests = (!($label =~ /BIG/) and ($label =~ /PSI/ or $label =~ /WEB/));
+
+my $big_limit = 100;    # XXX: this should be in a configuration file somewhere not hard coded
+
+if ($watch_for_big_requests and $nRows > $big_limit) {
+    $label = change_to_lower_priority_label($label);
+    $watch_for_big_requests = 0;
+}
 
 my $num_jobs = 0;
-my $imageList;
-my $stage;
-my $big_limit = 100;    # XXX: this should be in a configuration file some where
+
 foreach my $row (@$rows) {
-
-
-    if (!($label =~ /BIG/) and ($label =~ /PSI/ or $label =~ /WEB/) and ($nRows > $big_limit or $num_jobs > $big_limit)
-        and $req_id and !$no_update) {
-
-        # This is a "big" request and it came from one of the "high priority" channels
-        # and doesn't have a specific label assigned.
-        # Change the label to a value that its jobs run with lower priority.
-
-        my $old_label = $label;
-        $label = ($label =~ /WEB/) ? 'WEB.BIG' : 'PSI.BIG';
-        print "\nChanging label for big $old_label request to $label\n";
-
-        my $command = "$pstamptool -updatereq -req_id $req_id  -set_label $label";
-        my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
-            run(command => $command, verbose => $verbose);
-        unless ($success) {
-            my_die("$command failed", $PS_EXIT_UNKNOWN_ERROR);
-        }
-    }
 
     # validate the paramaters
@@ -276,4 +265,10 @@
 
     $num_jobs += processRow($action, $row);
+
+    # see whether number of jobs limit for high priority request was exceeded
+    if ($watch_for_big_requests and $num_jobs > $big_limit) {
+        $label = change_to_lower_priority_label($label);
+        $watch_for_big_requests = 0;
+    }
 }
 
@@ -286,4 +281,21 @@
 
 exit 0;
+
+# end of main function
+
+sub change_to_lower_priority_label {
+    my $label = shift;
+    my $old_label = $label;
+    $label = ($label =~ /WEB/) ? 'WEB.BIG' : 'PSI.BIG';
+    print "\nChanging label for big $old_label request to $label\n";
+
+    my $command = "$pstamptool -updatereq -req_id $req_id  -set_label $label";
+    my ( $success, $error_code, $full_buf, $stdout_buf, $stderr_buf ) =
+        run(command => $command, verbose => $verbose);
+    unless ($success) {
+        my_die("$command failed", $PS_EXIT_UNKNOWN_ERROR);
+    }
+    return $label;
+}
 
 sub checkRow {
@@ -494,5 +506,5 @@
     print "\nCalling locate_images_for_row for row: $rownum\n";
 
-    $imageList = locate_images_for_row($ipprc, $image_db, $camera, $row, $verbose);
+    my $imageList = locate_images_for_row($ipprc, $image_db, $camera, $row, $verbose);
 
     my $dtime_locate = gettimeofday() - $start_locate;
@@ -586,5 +598,5 @@
     # information required is contained there
 
-    $imageList = locate_images($ipprc, $image_db, $rowList, $req_type, $stage, $id, $tess_id, $component,
+    my $imageList = locate_images($ipprc, $image_db, $rowList, $req_type, $stage, $id, $tess_id, $component,
                 $option_mask, $need_magic, $mjd_min, $mjd_max, $filter, $data_group, $verbose);
 
@@ -777,4 +789,11 @@
             print "$image->{image}\n";
             ++$firstRow->{job_num};
+            if ($dump_params) {
+                my $rownum = $firstRow->{ROWNUM};
+                my $jobnum = $firstRow->{job_num};
+                my $filter = substr $image->{filter}, 0, 1;
+                my $output_base = "${rownum}_${jobnum}_${filter}";
+                write_params($output_base, $image);
+            }
         }
     } elsif ($job_type eq "get_image") {
Index: /branches/eam_branches/ipp-20130904/pstamp/test/gpc1/stacksummary.bycoord.all.txt
===================================================================
--- /branches/eam_branches/ipp-20130904/pstamp/test/gpc1/stacksummary.bycoord.all.txt	(revision 36192)
+++ /branches/eam_branches/ipp-20130904/pstamp/test/gpc1/stacksummary.bycoord.all.txt	(revision 36192)
@@ -0,0 +1,6 @@
+#  TEST: coord stack_summary
+#
+#  REQ_NAME EXTVER ACTION EMAIL
+CHANGEME 2 PROCESS null
+#  ROWNUM CENTER_X CENTER_Y WIDTH HEIGHT COORD_MASK JOB_TYPE OPTION_MASK PROJECT SURVEY_NAME IPP_RELEASE REQ_TYPE IMG_TYPE ID TESS_ID COMPONENT DATA_GROUP REQFILT MJD_MIN MJD_MAX RUN_TYPE FWHM_MIN FWHM_MAX | COMMENT
+1     359.767   -30.2009     100    100   2      stamp      197063         gpc1      3PI         null     bycoord   stack_summary  null RINGS.V3 null   LAP.ThreePI.20130717%      r        0      0        null      0        0    | 
Index: /branches/eam_branches/ipp-20130904/pstamp/test/gpc1/stacksummary.bycoord.txt
===================================================================
--- /branches/eam_branches/ipp-20130904/pstamp/test/gpc1/stacksummary.bycoord.txt	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/pstamp/test/gpc1/stacksummary.bycoord.txt	(revision 36192)
@@ -4,3 +4,3 @@
 CHANGEME 2 PROCESS null
 #  ROWNUM CENTER_X CENTER_Y WIDTH HEIGHT COORD_MASK JOB_TYPE OPTION_MASK PROJECT SURVEY_NAME IPP_RELEASE REQ_TYPE IMG_TYPE ID TESS_ID COMPONENT DATA_GROUP REQFILT MJD_MIN MJD_MAX RUN_TYPE FWHM_MIN FWHM_MAX | COMMENT
-1     359.767   -30.2009     100    100   2      stamp      455         gpc1      3PI         null     bycoord   stack_summary  null RINGS.V3 null   LAP.ThreePI.20130717%      r        0      0        null      0        0    | 
+1     359.767   -30.2009     100    100   2  stamp      196673        gpc1      3PI         null     bycoord   stack_summary  null RINGS.V3 null   LAP.ThreePI.20130717%      r        0      0        null      0        0    | 

Index: /branches/eam_branches/ipp-20130904/PS-IPP-PStamp/lib/PS/IPP/PStamp/Job.pm
===================================================================
--- /branches/eam_branches/ipp-20130904/PS-IPP-PStamp/lib/PS/IPP/PStamp/Job.pm	(revision 36191)
+++ /branches/eam_branches/ipp-20130904/PS-IPP-PStamp/lib/PS/IPP/PStamp/Job.pm	(revision 36192)
@@ -693,7 +693,8 @@
                 $out->{data_state} = $out->{state} = $out->{stack_state};
             } else {
-                # XXX: Consider looking up skycal results even if we are
+                $out->{data_state} = $out->{state};
+
+                # XXX: Consider looking up skycal and staticsky results even if we are
                 # not using releasetool
-                $out->{data_state} = $out->{state};
             }
         }
@@ -731,7 +732,13 @@
             $out->{mask}   = $ipprc->filename($mask_name,   $mask_base, $class_id) if $mask_name;
             $out->{weight} = $ipprc->filename($weight_name, $base, $class_id) if $weight_name;
-            $out->{cmf}    = $ipprc->filename($cmf_name,    $base, $class_id) if $cmf_name;
-            $out->{psf}    = $ipprc->filename($psf_name,    $base, $class_id) if $psf_name;
             $out->{backmdl}= $ipprc->filename($backmdl_name,$base, $class_id) if $backmdl_name;
+            if ($image->{staticsky_path_base}) {
+                $out->{psf}    = $ipprc->filename("PSPHOT.STACK.PSF.SAVE", $image->{staticsky_path_base}, $image->{stack_id});
+                # if astrom was not set above to the skycal cmf get the sources file from staticsky
+                $out->{cmf}    = $ipprc->filename("PSPHOT.STACK.OUTPUT",   $image->{staticsky_path_base}, $image->{stack_id}) if !$out->{astrom};
+            } else {
+                $out->{psf}    = $ipprc->filename($psf_name,    $base, $class_id) if $psf_name;
+                $out->{cmf}    = $ipprc->filename($cmf_name,    $base, $class_id) if $cmf_name;
+            }
         }
 
@@ -808,5 +815,5 @@
                         $command .= " -priority_order";
                     }
-                    $command .= " -surveyName $survey";
+                    $command .= " -surveyName $survey" if $survey;
                 } else {
                     $command = "$stacktool -dbname $imagedb";
@@ -2051,4 +2058,6 @@
     # see if we need to start the scs (skycell server)
 
+    my $very_verbose = 0;
+
     if (!$scs_tess_id or ($scs_tess_id ne $tess_id)) {
         if ($scs_tess_id) {
@@ -2076,4 +2085,5 @@
 
         # start an scs
+        print "Starting skycell server for $tess_dir_resolved.\n";
 
         # create pipes for communicating with the server
@@ -2111,5 +2121,5 @@
             my $command = "$dvoImagesAtCoords -D CATDIR $tess_dir_resolved -coords -";
 
-            print STDERR "SCS: execing $command\n";
+            print STDERR "SCS: execing $command\n" if $very_verbose;
 
             unless(exec $command) {
@@ -2146,5 +2156,4 @@
     }
 
-    my $very_verbose = 0;
     print STDERR "  sent coordinates to skycell server\n" if $very_verbose;
 